@@ -22,14 +22,6 @@
 #endif
 #include "osi_compat.h"
 
-#ifndef CURRENT_TIME
-# ifdef IATTR_TAKES_64BIT_TIME
-#  define CURRENT_TIME		(current_kernel_time64())
-# else
-#  define CURRENT_TIME            (current_kernel_time())
-# endif
-#endif
-
 int cache_fh_type = -1;
 int cache_fh_len = -1;
 
@@ -64,17 +56,14 @@ afs_linux_raw_open(afs_dcache_id_t *ainode)
 
 #if defined(STRUCT_TASK_STRUCT_HAS_CRED)
     /* Use stashed credentials - prevent selinux/apparmor problems  */
-    filp = afs_dentry_open(dp, afs_cacheMnt, O_RDWR, cache_creds);
+    filp = afs_dentry_open(dp, mntget(afs_cacheMnt), O_RDWR, cache_creds);
     if (IS_ERR(filp))
-	filp = afs_dentry_open(dp, afs_cacheMnt, O_RDWR, current_cred());
+	filp = afs_dentry_open(dp, mntget(afs_cacheMnt), O_RDWR, current_cred());
 #else
-    filp = dentry_open(dget(dp), mntget(afs_cacheMnt), O_RDWR);
+    filp = dentry_open(dp, mntget(afs_cacheMnt), O_RDWR);
 #endif
     if (IS_ERR(filp))
 	osi_Panic("Can't open file: %d\n", (int) PTR_ERR(filp));
-
-    dput(dp);
-
     return filp;
 }
 
@@ -94,8 +83,8 @@ osi_UFSOpen(afs_dcache_id_t *ainode)
 	crhold(&afs_osi_cred);	/* don't let it evaporate, since it is static */
 	afs_osicred_initialized = 1;
     }
-    afile = (struct osi_file *)osi_AllocLargeSpace(sizeof(struct osi_file));
     AFS_GUNLOCK();
+    afile = kmalloc(sizeof(struct osi_file), GFP_NOFS);
     if (!afile) {
 	osi_Panic("osi_UFSOpen: Failed to allocate %d bytes for osi_file.\n",
 		  (int)sizeof(struct osi_file));
@@ -160,8 +149,7 @@ osi_UFSClose(struct osi_file *afile)
 	    filp_close(afile->filp, NULL);
 	}
     }
-
-    osi_FreeLargeSpace(afile);
+    kfree(afile);
     return 0;
 }
 
@@ -192,11 +180,7 @@ osi_UFSTruncate(struct osi_file *afile, afs_int32 asize)
     newattrs.ia_ctime = CURRENT_TIME;
 
     /* avoid notify_change() since it wants to update dentry->d_parent */
-#ifdef HAVE_LINUX_SETATTR_PREPARE
-    code = setattr_prepare(file_dentry(afile->filp), &newattrs);
-#else
     code = inode_change_ok(inode, &newattrs);
-#endif
     if (!code)
 	code = afs_inode_setattr(afile, &newattrs);
     if (!code)
@@ -221,9 +205,6 @@ afs_osi_Read(struct osi_file *afile, int offset, void *aptr,
     struct iovec iov;
     afs_int32 code;
 
-    memset(&auio, 0, sizeof(auio));
-    memset(&iov, 0, sizeof(iov));
-
     AFS_STATCNT(osi_Read);
 
     /*
@@ -231,7 +212,7 @@ afs_osi_Read(struct osi_file *afile, int offset, void *aptr,
      * down. No point in crashing when we are already shutting down
      */
     if (!afile) {
-	if (afs_shuttingdown == AFS_RUNNING)
+	if (!afs_shuttingdown)
 	    osi_Panic("osi_Read called with null param");
 	else
 	    return -EIO;
@@ -250,7 +231,7 @@ afs_osi_Read(struct osi_file *afile, int offset, void *aptr,
 	afs_Trace2(afs_iclSetp, CM_TRACE_READFAILED, ICL_TYPE_INT32, auio.uio_resid,
 		   ICL_TYPE_INT32, code);
 	if (code > 0) {
-	    code *= -1;
+	    code = -code;
 	}
     }
     return code;
@@ -265,13 +246,10 @@ afs_osi_Write(struct osi_file *afile, afs_int32 offset, void *aptr,
     struct iovec iov;
     afs_int32 code;
 
-    memset(&auio, 0, sizeof(auio));
-    memset(&iov, 0, sizeof(iov));
-
     AFS_STATCNT(osi_Write);
 
     if (!afile) {
-	if (afs_shuttingdown == AFS_RUNNING)
+	if (!afs_shuttingdown)
 	    osi_Panic("afs_osi_Write called with null param");
 	else
 	    return -EIO;
@@ -291,7 +269,7 @@ afs_osi_Write(struct osi_file *afile, afs_int32 offset, void *aptr,
 	    afs_warnuser
 		("\n\n\n*** Cache partition is FULL - Decrease cachesize!!! ***\n\n");
 	if (code > 0) {
-	    code *= -1;
+	    code = -code;
 	}
     }
 
@@ -361,9 +339,7 @@ int
 osi_rdwr(struct osi_file *osifile, struct uio *uiop, int rw)
 {
     struct file *filp = osifile->filp;
-#ifdef AFS_FILE_NEEDS_SET_FS
     mm_segment_t old_fs = {0};
-#endif /* AFS_FILE_NEEDS_SET_FS */
     int code = 0;
     struct iovec *iov;
     size_t count;
@@ -373,13 +349,11 @@ osi_rdwr(struct osi_file *osifile, struct uio *uiop, int rw)
     savelim = current->TASK_STRUCT_RLIM[RLIMIT_FSIZE].rlim_cur;
     current->TASK_STRUCT_RLIM[RLIMIT_FSIZE].rlim_cur = RLIM_INFINITY;
 
-#ifdef AFS_FILE_NEEDS_SET_FS
     if (uiop->uio_seg == AFS_UIOSYS) {
 	/* Switch into user space */
 	old_fs = get_fs();
 	set_fs(get_ds());
     }
-#endif /* AFS_FILE_NEEDS_SET_FS */
 
     while (code == 0 && uiop->uio_resid > 0 && uiop->uio_iovcnt > 0) {
 	iov = uiop->uio_iov;
@@ -392,9 +366,9 @@ osi_rdwr(struct osi_file *osifile, struct uio *uiop, int rw)
 
 	pos = uiop->uio_offset;
 	if (rw == UIO_READ)
-	    code = afs_file_read(filp, iov->iov_base, count, &pos);
+	    code = filp->f_op->read(filp, iov->iov_base, count, &pos);
 	else
-	    code = afs_file_write(filp, iov->iov_base, count, &pos);
+	    code = filp->f_op->write(filp, iov->iov_base, count, &pos);
 
 	if (code < 0) {
 	    code = -code;
@@ -416,12 +390,10 @@ osi_rdwr(struct osi_file *osifile, struct uio *uiop, int rw)
 	code = 0;
     }
 
-#ifdef AFS_FILE_NEEDS_SET_FS
     if (uiop->uio_seg == AFS_UIOSYS) {
 	/* Switch back into kernel space */
 	set_fs(old_fs);
     }
-#endif /* AFS_FILE_NEEDS_SET_FS */
 
     current->TASK_STRUCT_RLIM[RLIMIT_FSIZE].rlim_cur = savelim;
 
