@@ -41,18 +41,21 @@ extern struct vfs *afs_globalVFS;
 
 /* copy out attributes from cache entry */
 int
-afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
+afs_CopyOutAttrs(struct vcache *avc, struct vattr *attrs)
 {
-    register struct volume *tvp;
-    register struct cell *tcell;
+    struct volume *tvp;
+    struct cell *tcell;
+#if defined(AFS_FBSD_ENV) || defined(AFS_DFBSD_ENV)
+    struct vnode *vp = AFSTOV(avc);
+#endif
     int fakedir = 0;
 
     AFS_STATCNT(afs_CopyOutAttrs);
     if (afs_fakestat_enable && avc->mvstat == 1)
 	fakedir = 1;
     attrs->va_type = fakedir ? VDIR : vType(avc);
-#if defined(AFS_SGI_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_SUN5_ENV)
-    attrs->va_mode = fakedir ? 0755 : (mode_t) (avc->f.m.Mode & 0xffff);
+#if defined(AFS_SGI_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DARWIN_ENV)
+    attrs->va_mode = fakedir ? S_IFDIR | 0755 : (mode_t) (avc->f.m.Mode & 0xffff);
 #else
     attrs->va_mode = fakedir ? VDIR | 0755 : avc->f.m.Mode;
 #endif
@@ -65,7 +68,6 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
     }
 #if defined(AFS_DARWIN_ENV)
     {
-	extern u_int32_t afs_darwin_realmodes;
 	if (!afs_darwin_realmodes) {
 	    /* Mac OS X uses the mode bits to determine whether a file or
 	     * directory is accessible, and believes them, even though under
@@ -88,13 +90,13 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 #endif /* AFS_DARWIN_ENV */
     attrs->va_uid = fakedir ? 0 : avc->f.m.Owner;
     attrs->va_gid = fakedir ? 0 : avc->f.m.Group;	/* yeah! */
-#if defined(AFS_SUN56_ENV)
+#if defined(AFS_SUN5_ENV)
     attrs->va_fsid = avc->v.v_vfsp->vfs_fsid.val[0];
 #elif defined(AFS_DARWIN80_ENV)
     VATTR_RETURN(attrs, va_fsid, vfs_statfs(vnode_mount(AFSTOV(avc)))->f_fsid.val[0]);
-#elif defined(AFS_DARWIN70_ENV)
+#elif defined(AFS_DARWIN_ENV)
     attrs->va_fsid = avc->v->v_mount->mnt_stat.f_fsid.val[0];
-#else /* ! AFS_DARWIN70_ENV */
+#else /* ! AFS_DARWIN_ENV */
     attrs->va_fsid = 1;
 #endif 
     if (avc->mvstat == 2) {
@@ -102,8 +104,9 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 	/* The mount point's vnode. */
 	if (tvp) {
 	    attrs->va_nodeid =
-	      afs_calc_inum (tvp->mtpoint.Fid.Volume,
-			      tvp->mtpoint.Fid.Vnode);
+	      afs_calc_inum(tvp->mtpoint.Cell,
+			    tvp->mtpoint.Fid.Volume,
+			    tvp->mtpoint.Fid.Vnode);
 	    if (FidCmp(&afs_rootFid, &avc->f.fid) && !attrs->va_nodeid)
 		attrs->va_nodeid = 2;
 	    afs_PutVolume(tvp, READ_LOCK);
@@ -111,11 +114,15 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 	    attrs->va_nodeid = 2;
     } else
 	attrs->va_nodeid = 
-	      afs_calc_inum (avc->f.fid.Fid.Volume,
-			      avc->f.fid.Fid.Vnode);
+	      afs_calc_inum(avc->f.fid.Cell,
+			    avc->f.fid.Fid.Volume,
+			    avc->f.fid.Fid.Vnode);
     attrs->va_nodeid &= 0x7fffffff;	/* Saber C hates negative inode #s! */
     attrs->va_nlink = fakedir ? 100 : avc->f.m.LinkCount;
     attrs->va_size = fakedir ? 4096 : avc->f.m.Length;
+#if defined(AFS_FBSD_ENV) || defined(AFS_DFBSD_ENV)
+        vnode_pager_setsize(vp, (u_long) attrs->va_size);
+#endif
     attrs->va_atime.tv_sec = attrs->va_mtime.tv_sec = attrs->va_ctime.tv_sec =
 	fakedir ? 0 : (int)avc->f.m.Date;
     /* set microseconds to be dataversion # so that we approximate NFS-style
@@ -132,7 +139,7 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
     attrs->va_atime.tv_nsec = attrs->va_mtime.tv_nsec =
 	attrs->va_ctime.tv_nsec = 0;
     attrs->va_gen = hgetlo(avc->f.m.DataVersion);
-#elif defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV) || defined(AFS_OBSD_ENV)
+#elif defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV) || defined(AFS_OBSD_ENV) || defined(AFS_NBSD_ENV)
     attrs->va_atime.tv_nsec = attrs->va_mtime.tv_nsec =
 	attrs->va_ctime.tv_nsec =
 	(hgetlo(avc->f.m.DataVersion) & 0x7ffff) * 1000;
@@ -189,6 +196,7 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
     afs_int32 code;
     struct vrequest treq;
     struct unixuser *au;
+    int inited = 0;
     OSI_VC_CONVERT(avc);
 
     AFS_STATCNT(afs_getattr);
@@ -212,23 +220,15 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
 	afs_PutFakeStat(&fakestat);
 	return code;
     }
-
-#if defined(AFS_SUN5_ENV) || defined(AFS_DARWIN_ENV) && !defined(AFS_DARWIN80_ENV)
 #if defined(AFS_SUN5_ENV)
-	if (flags & ATTR_HINT)
-#else
-	if (avc->f.states & CUBCinit)
+    if (flags & ATTR_HINT) {
+	code = afs_CopyOutAttrs(avc, attrs);
+	return code;
+    }
 #endif
-    {
-	if (!(code = afs_InitReq(&treq, acred))) {
-	    if (vType(avc) != VDIR && vType(avc) != VLNK &&
-	        !afs_AccessOK(avc, PRSFS_READ, &treq, DONT_CHECK_MODE_BITS)) {
-
-		code = EACCES;
-	    }
-	    if (!code)
-		code = afs_CopyOutAttrs(avc, attrs);
-	}
+#if defined(AFS_DARWIN_ENV) && !defined(AFS_DARWIN80_ENV)
+    if (avc->f.states & CUBCinit) {
+	code = afs_CopyOutAttrs(avc, attrs);
 	return code;
     }
 #endif
@@ -242,29 +242,33 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
     if (afs_shuttingdown)
 	return EIO;
 
-    code = afs_InitReq(&treq, acred);
+    if (!(avc->f.states & CStatd)) {
+	if (!(code = afs_InitReq(&treq, acred))) {
+	    code = afs_VerifyVCache2(avc, &treq);
+	    inited = 1;
+	}
+    } else
+	code = 0;
 
-    if (code == 0 && !(avc->f.states & CStatd)) {
-	code = afs_VerifyVCache2(avc, &treq);
-    }
-
-#ifdef AFS_BOZONLOCK_ENV
+#if defined(AFS_SUN5_ENV) || defined(AFS_BOZONLOCK_ENV)
     if (code == 0)
 	osi_FlushPages(avc, acred);
+#endif
+#ifdef AFS_BOZONLOCK_ENV
     afs_BozonUnlock(&avc->pvnLock, avc);
 #endif
 
-    if (code == 0 && vType(avc) != VDIR && vType(avc) != VLNK &&
-        !afs_AccessOK(avc, PRSFS_READ, &treq, DONT_CHECK_MODE_BITS)) {
-
-	code = EACCES;
-    }
 
     if (code == 0) {
 	osi_FlushText(avc);	/* only needed to flush text if text locked last time */
 	code = afs_CopyOutAttrs(avc, attrs);
 
 	if (afs_nfsexporter) {
+	    if (!inited) {
+		if ((code = afs_InitReq(&treq, acred)))
+		    return code;
+		inited = 1;
+	    }
 	    if (AFS_NFSXLATORREQ(acred)) {
 		if ((vType(avc) != VDIR)
 		    && !afs_AccessOK(avc, PRSFS_READ, &treq,
@@ -274,7 +278,7 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
 		}
 	    }
 	    if ((au = afs_FindUser(treq.uid, -1, READ_LOCK))) {
-		register struct afs_exporter *exporter = au->exporter;
+		struct afs_exporter *exporter = au->exporter;
 
 		if (exporter && !(afs_nfsexporter->exp_states & EXP_UNIXMODE)) {
 		    unsigned int ubits;
@@ -299,8 +303,10 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
 		    }
 #else
 		    if (
-#ifdef AFS_DARWIN_ENV		    
+#if defined(AFS_DARWIN_ENV)
 			vnode_isvroot(AFSTOV(avc))
+#elif defined(AFS_NBSD50_ENV)
+			AFSTOV(avc)->v_vflag & VV_ROOT
 #else
 			AFSTOV(avc)->v_flag & VROOT
 #endif
@@ -342,10 +348,10 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
 
 /* convert a Unix request into a status store request */
 int
-afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
-	      register struct AFSStoreStatus *as)
+afs_VAttrToAS(struct vcache *avc, struct vattr *av,
+	      struct AFSStoreStatus *as)
 {
-    register int mask;
+    int mask;
     mask = 0;
     AFS_STATCNT(afs_VAttrToAS);
 #if     defined(AFS_DARWIN80_ENV)
@@ -440,17 +446,20 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
  */
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 int
-afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs, int flags,
+afs_setattr(OSI_VC_DECL(avc), struct vattr *attrs, int flags,
 	    afs_ucred_t *acred)
 #else
 int
-afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
+afs_setattr(OSI_VC_DECL(avc), struct vattr *attrs,
 	    afs_ucred_t *acred)
 #endif
 {
     struct vrequest treq;
     struct AFSStoreStatus astat;
-    register afs_int32 code;
+    afs_int32 code;
+#if defined(AFS_FBSD_ENV) || defined(AFS_DFBSD_ENV)
+    struct vnode *vp = AFSTOV(avc);
+#endif
     struct afs_fakestat_state fakestate;
     OSI_VC_CONVERT(avc);
 
@@ -559,6 +568,9 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
 	 * pdflush */
 	if (code == 0)
 	    i_size_write(AFSTOV(avc), tsize);
+#endif
+#if defined(AFS_FBSD_ENV) || defined(AFS_DFBSD_ENV)
+        vnode_pager_setsize(vp, (u_long) tsize);
 #endif
 	/* if date not explicitly set by this call, set it ourselves, since we
 	 * changed the data */
@@ -602,15 +614,11 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
 	        osi_dnlc_purgedp(avc);
 	    /* error?  erase any changes we made to vcache entry */
         }
-
-#if defined(AFS_DISCON_ENV)
     } else {
-
 	ObtainSharedLock(&avc->lock, 712);
 	/* Write changes locally. */
 	code = afs_WriteVCacheDiscon(avc, &astat, attrs);
 	ReleaseSharedLock(&avc->lock);
-#endif
     }		/* if (!AFS_IS_DISCONNECTED) */
 
 #if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
