@@ -140,6 +140,7 @@ afs_Daemon(void)
     afs_int32 last3MinCheck, last10MinCheck, last60MinCheck, lastNMinCheck;
     afs_int32 last1MinCheck, last5MinCheck;
     afs_uint32 lastCBSlotBump;
+    char cs_warned = 0;
 
     AFS_STATCNT(afs_Daemon);
     last1MinCheck = last3MinCheck = last60MinCheck = last10MinCheck =
@@ -180,6 +181,7 @@ afs_Daemon(void)
 	if (afs_nfsexporter)
 	    afs_FlushActiveVcaches(0);	/* flush NFS writes */
 	afs_FlushVCBs(1);	/* flush queued callbacks */
+
 	afs_MaybeWakeupTruncateDaemon();	/* free cache space if have too */
 	rx_CheckPackets();	/* Does RX need more packets? */
 
@@ -225,6 +227,11 @@ afs_Daemon(void)
         }
 
 	if (!afs_CheckServerDaemonStarted) {
+	    /* Do the check here if the correct afsd is not installed. */
+	    if (!cs_warned) {
+		cs_warned = 1;
+		afs_warn("Please install afsd with check server daemon.\n");
+	    }
 	    if (lastNMinCheck + afs_probe_interval < now) {
 		/* only check down servers */
 		afs_CheckServers(1, NULL);
@@ -357,14 +364,70 @@ afs_CheckRootVolume(void)
 		 * count to zero and fs checkv is executed when the current
 		 * directory is /afs.
 		 */
-#ifdef AFS_LINUX22_ENV
-		osi_ResetRootVCache(volid);
+#ifdef AFS_LINUX20_ENV
+		{
+		    struct vrequest treq;
+		    struct vattr vattr;
+		    cred_t *credp;
+		    struct dentry *dp;
+		    struct vcache *vcp;
+
+		    afs_rootFid.Fid.Volume = volid;
+		    afs_rootFid.Fid.Vnode = 1;
+		    afs_rootFid.Fid.Unique = 1;
+
+		    credp = crref();
+		    if (afs_InitReq(&treq, credp))
+			goto out;
+		    vcp = afs_GetVCache(&afs_rootFid, &treq, NULL, NULL);
+		    if (!vcp)
+			goto out;
+		    afs_getattr(vcp, &vattr, credp);
+		    afs_fill_inode(AFSTOV(vcp), &vattr);
+
+		    dp = d_find_alias(AFSTOV(afs_globalVp));
+
+#if defined(AFS_LINUX24_ENV)
+#if defined(HAVE_DCACHE_LOCK)
+		    spin_lock(&dcache_lock);
 #else
-# ifdef AFS_DARWIN80_ENV
+		    spin_lock(&AFSTOV(vcp)->i_lock);
+#endif
+#if defined(AFS_LINUX26_ENV)
+		    spin_lock(&dp->d_lock);
+#endif
+#endif
+#if defined(D_ALIAS_IS_HLIST)
+		    hlist_del_init(&dp->d_alias);
+		    hlist_add_head(&dp->d_alias, &(AFSTOV(vcp)->i_dentry));
+#else
+		    list_del_init(&dp->d_alias);
+		    list_add(&dp->d_alias, &(AFSTOV(vcp)->i_dentry));
+#endif
+		    dp->d_inode = AFSTOV(vcp);
+#if defined(AFS_LINUX24_ENV)
+#if defined(AFS_LINUX26_ENV)
+		    spin_unlock(&dp->d_lock);
+#endif
+#if defined(HAVE_DCACHE_LOCK)
+		    spin_unlock(&dcache_lock);
+#else
+		    spin_unlock(&AFSTOV(vcp)->i_lock);
+#endif
+#endif
+		    dput(dp);
+
+		    AFS_FAST_RELE(afs_globalVp);
+		    afs_globalVp = vcp;
+		out:
+		    crfree(credp);
+		}
+#else
+#ifdef AFS_DARWIN80_ENV
 		afs_PutVCache(afs_globalVp);
-# else
+#else
 		AFS_FAST_RELE(afs_globalVp);
-# endif
+#endif
 		afs_globalVp = 0;
 #endif
 	    }
@@ -395,13 +458,12 @@ BPath(struct brequest *ab)
     struct dentry *dp = NULL;
 #endif
     afs_size_t offset, len;
-    struct vrequest *treq = NULL;
+    struct vrequest treq;
     afs_int32 code;
 
     AFS_STATCNT(BPath);
-    if ((code = afs_CreateReq(&treq, ab->cred))) {
+    if ((code = afs_InitReq(&treq, ab->cred)))
 	return;
-    }
     AFS_GUNLOCK();
 #ifdef AFS_LINUX22_ENV
     code = gop_lookupname((char *)ab->ptr_parm[0], AFS_UIOSYS, 1, &dp);
@@ -412,10 +474,8 @@ BPath(struct brequest *ab)
 #endif
     AFS_GLOCK();
     osi_FreeLargeSpace((char *)ab->ptr_parm[0]);	/* free path name buffer here */
-    if (code) {
-	afs_DestroyReq(treq);
+    if (code)
 	return;
-    }
     /* now path may not have been in afs, so check that before calling our cache manager */
     if (!tvn || !IsAfsVnode(tvn)) {
 	/* release it and give up */
@@ -426,12 +486,11 @@ BPath(struct brequest *ab)
 	    AFS_RELE(tvn);
 #endif
 	}
-	afs_DestroyReq(treq);
 	return;
     }
     tvc = VTOAFS(tvn);
     /* here we know its an afs vnode, so we can get the data for the chunk */
-    tdc = afs_GetDCache(tvc, ab->size_parm[0], treq, &offset, &len, 1);
+    tdc = afs_GetDCache(tvc, ab->size_parm[0], &treq, &offset, &len, 1);
     if (tdc) {
 	afs_PutDCache(tdc);
     }
@@ -440,7 +499,6 @@ BPath(struct brequest *ab)
 #else
     AFS_RELE(tvn);
 #endif
-    afs_DestroyReq(treq);
 }
 
 /* size_parm 0 to the fetch is the chunk number,
@@ -453,16 +511,15 @@ BPrefetch(struct brequest *ab)
     struct dcache *tdc;
     struct vcache *tvc;
     afs_size_t offset, len, abyte, totallen = 0;
-    struct vrequest *treq = NULL;
-    int code;
+    struct vrequest treq;
 
     AFS_STATCNT(BPrefetch);
-    if ((code = afs_CreateReq(&treq, ab->cred)))
+    if ((len = afs_InitReq(&treq, ab->cred)))
 	return;
     abyte = ab->size_parm[0];
     tvc = ab->vc;
     do {
-	tdc = afs_GetDCache(tvc, abyte, treq, &offset, &len, 1);
+	tdc = afs_GetDCache(tvc, abyte, &treq, &offset, &len, 1);
 	if (tdc) {
 	    afs_PutDCache(tdc);
 	}
@@ -486,24 +543,22 @@ BPrefetch(struct brequest *ab)
     if (ab->size_parm[1]) {
 	afs_PutDCache(tdc);	/* put this one back, too */
     }
-    afs_DestroyReq(treq);
 }
 
 #if defined(AFS_CACHE_BYPASS)
 static void
 BPrefetchNoCache(struct brequest *ab)
 {
-    struct vrequest *treq = NULL;
-    int code;
+    struct vrequest treq;
+    afs_size_t len;
 
-    if ((code = afs_CreateReq(&treq, ab->cred)))
+    if ((len = afs_InitReq(&treq, ab->cred)))
 	return;
 
 #ifndef UKERNEL
     /* OS-specific prefetch routine */
     afs_PrefetchNoCache(ab->vc, ab->cred, (struct nocache_read_request *) ab->ptr_parm[0]);
 #endif
-    afs_DestroyReq(treq);
 }
 #endif
 
@@ -512,13 +567,13 @@ BStore(struct brequest *ab)
 {
     struct vcache *tvc;
     afs_int32 code;
-    struct vrequest *treq = NULL;
+    struct vrequest treq;
 #if defined(AFS_SGI_ENV)
     struct cred *tmpcred;
 #endif
 
     AFS_STATCNT(BStore);
-    if ((code = afs_CreateReq(&treq, ab->cred)))
+    if ((code = afs_InitReq(&treq, ab->cred)))
 	return;
     code = 0;
     tvc = ab->vc;
@@ -539,7 +594,7 @@ BStore(struct brequest *ab)
     AFS_RWLOCK((vnode_t *) tvc, 1);
 #endif
     ObtainWriteLock(&tvc->lock, 209);
-    code = afs_StoreOnLastReference(tvc, treq);
+    code = afs_StoreOnLastReference(tvc, &treq);
     ReleaseWriteLock(&tvc->lock);
 #if defined(AFS_SGI_ENV)
     OSI_SET_CURRENT_CRED(tmpcred);
@@ -547,24 +602,50 @@ BStore(struct brequest *ab)
 #endif
     /* now set final return code, and wakeup anyone waiting */
     if ((ab->flags & BUVALID) == 0) {
+	ab->code = afs_CheckCode(code, &treq, 43);	/* set final code, since treq doesn't go across processes */
+	ab->flags |= BUVALID;
+	if (ab->flags & BUWAIT) {
+	    ab->flags &= ~BUWAIT;
+	    afs_osi_Wakeup(ab);
+	}
+    }
+}
 
-	/* To explain code_raw/code_checkcode:
-	 * Anyone that's waiting won't have our treq, so they won't be able to
-	 * call afs_CheckCode themselves on the return code we provide here.
-	 * But if we give back only the afs_CheckCode value, they won't know
-	 * what the "raw" value was. So give back both values, so the waiter
-	 * can know the "raw" value for interpreting the value internally, as
-	 * well as the afs_CheckCode value to give to the OS. */
-	ab->code_raw = code;
-	ab->code_checkcode = afs_CheckCode(code, treq, 43);
+static void
+BPartialStore(struct brequest *ab)
+{
+    struct vcache *tvc;
+    afs_int32 code;
+    struct vrequest treq;
+    int locked, shared_locked = 0;
 
+    AFS_STATCNT(BStore);
+    if ((code = afs_InitReq(&treq, ab->cred)))
+	return;
+    code = 0;
+    tvc = ab->vc;
+    locked = tvc->lock.excl_locked? 1:0;
+    if (!locked)
+        ObtainWriteLock(&tvc->lock, 1209);
+    else if (!(tvc->lock.excl_locked & WRITE_LOCK)) {
+	shared_locked = 1;
+	ConvertSToRLock(&tvc->lock);
+    }
+    code = afs_StoreAllSegments(tvc, &treq, AFS_ASYNC);
+    if (!locked)
+	ReleaseWriteLock(&tvc->lock);
+    else if (shared_locked)
+	ConvertSToRLock(&tvc->lock);
+    /* now set final return code, and wakeup anyone waiting */
+    if ((ab->flags & BUVALID) == 0) {
+	/* set final code, since treq doesn't go across processes */
+	ab->code = afs_CheckCode(code, &treq, 43);
 	ab->flags |= BUVALID;
 	if (ab->flags & BUWAIT) {
 	    ab->flags &= ~BUWAIT;
 	    afs_osi_Wakeup(ab);
 	}
     }
-    afs_DestroyReq(treq);
 }
 
 /* release a held request buffer */
@@ -625,7 +706,7 @@ afs_BQueue(short aopcode, struct vcache *avc,
 	    tb->ptr_parm[1] = apparm1;
 	    tb->ptr_parm[2] = apparm2;
 	    tb->flags = 0;
-	    tb->code_raw = tb->code_checkcode = 0;
+	    tb->code = 0;
 	    tb->ts = afs_brs_count++;
 	    /* if daemons are waiting for work, wake them up */
 	    if (afs_brsDaemons > 0) {
@@ -955,7 +1036,7 @@ brequest_release(struct brequest *tb)
     afs_BRelease(tb);  /* this grabs and releases afs_xbrs lock */
 }
 
-#ifdef AFS_DARWIN80_ENV
+#ifdef AFS_NEW_BKG
 int
 afs_BackgroundDaemon(struct afs_uspc_param *uspc, void *param1, void *param2)
 #else
@@ -972,7 +1053,7 @@ afs_BackgroundDaemon(void)
 	/* Irix with "short stack" exits */
 	afs_BackgroundDaemon_once();
 
-#ifdef AFS_DARWIN80_ENV
+#ifdef AFS_NEW_BKG
     /* If it's a re-entering syscall, complete the request and release */
     if (uspc->ts > -1) {
         tb = afs_brs;
@@ -996,7 +1077,7 @@ afs_BackgroundDaemon(void)
 #endif
         /* Otherwise it's a new one */
 	afs_nbrs++;
-#ifdef AFS_DARWIN80_ENV
+#ifdef AFS_NEW_BKG
     }
 #endif
 
@@ -1010,7 +1091,7 @@ afs_BackgroundDaemon(void)
 		afs_termState = AFSOP_STOP_RXCALLBACK;
 	    ReleaseWriteLock(&afs_xbrs);
 	    afs_osi_Wakeup(&afs_termState);
-#ifdef AFS_DARWIN80_ENV
+#ifdef AFS_NEW_BKG
 	    return -2;
 #else
 	    return;
@@ -1060,6 +1141,8 @@ afs_BackgroundDaemon(void)
                 return 0;
             }
 #endif
+	    else if (tb->opcode == BOP_PARTIAL_STORE)
+		BPartialStore(tb);
 	    else
 		panic("background bop");
 	    brequest_release(tb);
@@ -1074,7 +1157,7 @@ afs_BackgroundDaemon(void)
 	    afs_brsDaemons--;
 	}
     }
-#ifdef AFS_DARWIN80_ENV
+#ifdef AFS_NEW_BKG
     return -2;
 #endif
 }
