@@ -27,8 +27,8 @@
 extern int cacheDiskType;
 
 #ifndef AFS_NOSTATS
-void
-FillStoreStats(int code, int idx, osi_timeval_t *xferStartTime,
+static void
+FillStoreStats(int code, int idx, osi_timeval_t xferStartTime,
 	       afs_size_t bytesToXfer, afs_size_t bytesXferred)
 {
     struct afs_stats_xferData *xferP;
@@ -63,7 +63,7 @@ FillStoreStats(int code, int idx, osi_timeval_t *xferStartTime,
 	else
 	    (xferP->count[8])++;
 
-	afs_stats_GetDiff(elapsedTime, (*xferStartTime), xferStopTime);
+	afs_stats_GetDiff(elapsedTime, xferStartTime, xferStopTime);
 	afs_stats_AddTo((xferP->sumTime), elapsedTime);
 	afs_stats_SquareAddTo((xferP->sqrTime), elapsedTime);
 	if (afs_stats_TimeLessThan(elapsedTime, (xferP->minTime))) {
@@ -362,9 +362,9 @@ struct storeOps rxfs_storeMemOps = {
 
 afs_int32
 rxfs_storeInit(struct vcache *avc, struct afs_conn *tc,
-	       struct rx_connection *rxconn, afs_size_t base,
-	       afs_size_t bytes, afs_size_t length,
-	       int sync, struct storeOps **ops, void **rock)
+                struct rx_connection *rxconn, afs_size_t base,
+		afs_size_t bytes, afs_size_t length,
+		int sync, struct storeOps **ops, void **rock)
 {
     afs_int32 code;
     struct rxfs_storeVariables *v;
@@ -372,7 +372,7 @@ rxfs_storeInit(struct vcache *avc, struct afs_conn *tc,
     if ( !tc )
 	return -1;
 
-    v = (struct rxfs_storeVariables *) osi_AllocSmallSpace(sizeof(struct rxfs_storeVariables));
+    v = osi_AllocSmallSpace(sizeof(struct rxfs_storeVariables));
     if (!v)
         osi_Panic("rxfs_storeInit: osi_AllocSmallSpace returned NULL\n");
     memset(v, 0, sizeof(struct rxfs_storeVariables));
@@ -383,14 +383,14 @@ rxfs_storeInit(struct vcache *avc, struct afs_conn *tc,
     if (sync & AFS_SYNC)
         v->InStatus.Mask |= AFS_FSYNC;
     RX_AFS_GUNLOCK();
-    v->call = rx_NewCall(tc->id);
+    v->call = rx_NewCall(rxconn);
     if (v->call) {
 #ifdef AFS_64BIT_CLIENT
 	if (!afs_serverHasNo64Bit(tc))
 	    code = StartRXAFS_StoreData64(
-	    			v->call, (struct AFSFid*)&avc->f.fid.Fid,
-				&v->InStatus, base, bytes, length);
-	else
+		v->call, (struct AFSFid*)&avc->f.fid.Fid,
+		&v->InStatus, base, bytes, length);
+	else {
 	    if (length > 0xFFFFFFFF)
 		code = EFBIG;
 	    else {
@@ -399,6 +399,8 @@ rxfs_storeInit(struct vcache *avc, struct afs_conn *tc,
 					(struct AFSFid *) &avc->f.fid.Fid,
 					 &v->InStatus, t1, t2, t3);
 	    }
+	    v->hasNo64bit = 1;
+	}
 #else /* AFS_64BIT_CLIENT */
 	code = StartRXAFS_StoreData(v->call, (struct AFSFid *)&avc->f.fid.Fid,
 				    &v->InStatus, base, bytes, length);
@@ -463,7 +465,6 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 {
     int *shouldwake = NULL;
     unsigned int i;
-    int stored = 0;
     afs_int32 code = 0;
     afs_size_t bytesXferred;
 
@@ -472,15 +473,19 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
     afs_size_t bytesToXfer = 10000;	/* # bytes to xfer */
 #endif /* AFS_NOSTATS */
     XSTATS_DECLS;
+    osi_Assert(nchunks != 0);
 
     for (i = 0; i < nchunks && !code; i++) {
+	int stored = 0;
 	struct dcache *tdc = dclist[i];
-	afs_int32 size = tdc->f.chunkBytes;
+	afs_int32 size;
+
 	if (!tdc) {
 	    afs_warn("afs: missing dcache!\n");
 	    storeallmissing++;
 	    continue;	/* panic? */
 	}
+	size = tdc->f.chunkBytes;
 	afs_Trace4(afs_iclSetp, CM_TRACE_STOREALL2, ICL_TYPE_POINTER, avc,
 		    ICL_TYPE_INT32, tdc->f.chunk, ICL_TYPE_INT32, tdc->index,
 		    ICL_TYPE_INT32, afs_inode2trace(&tdc->f.inode));
@@ -522,7 +527,7 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 
 #ifndef AFS_NOSTATS
 	FillStoreStats(code, AFS_STATS_FS_XFERIDX_STOREDATA,
-		    &xferStartTime, bytesToXfer, bytesXferred);
+		    xferStartTime, bytesToXfer, bytesXferred);
 #endif /* AFS_NOSTATS */
 
 	if ((tdc->f.chunkBytes < afs_OtherCSize)
@@ -634,7 +639,7 @@ afs_CacheStoreVCache(struct dcache **dcList, struct vcache *avc,
 		       ICL_HANDLE_OFFSET(length));
 
 	    do {
-		tc = afs_Conn(&avc->f.fid, areq, 0, &rxconn);
+	        tc = afs_Conn(&avc->f.fid, areq, 0, &rxconn);
 
 #ifdef AFS_64BIT_CLIENT
 	      restart:
@@ -904,7 +909,7 @@ struct fetchOps rxfs_fetchMemOps = {
 
 afs_int32
 rxfs_fetchInit(struct afs_conn *tc, struct rx_connection *rxconn,
-	       struct vcache *avc, afs_offs_t base,
+               struct vcache *avc, afs_offs_t base,
 	       afs_uint32 size, afs_int32 *alength, struct dcache *adc,
 	       struct osi_file *fP, struct fetchOps **ops, void **rock)
 {
@@ -967,6 +972,7 @@ rxfs_fetchInit(struct afs_conn *tc, struct rx_connection *rxconn,
 		RX_AFS_GLOCK();
 	    }
 	    afs_serverSetNo64Bit(tc);
+	    v->hasNo64bit = 1;
 	}
 	if (!code) {
 	    RX_AFS_GUNLOCK();
@@ -1063,7 +1069,7 @@ rxfs_fetchInit(struct afs_conn *tc, struct rx_connection *rxconn,
  * Routine called on fetch; also tells people waiting for data
  *	that more has arrived.
  *
- * \param tc Ptr to the Rx connection structure.
+ * \param tc Ptr to the AFS connection structure.
  * \param rxconn Ptr to the Rx connection structure.
  * \param fP File descriptor for the cache file.
  * \param base Base offset to fetch.
@@ -1076,7 +1082,7 @@ rxfs_fetchInit(struct afs_conn *tc, struct rx_connection *rxconn,
  */
 int
 afs_CacheFetchProc(struct afs_conn *tc, struct rx_connection *rxconn,
-		   struct osi_file *fP, afs_size_t base,
+                   struct osi_file *fP, afs_size_t base,
 		   struct dcache *adc, struct vcache *avc, afs_int32 size,
 		   struct afs_FetchOutput *tsmall)
 {
@@ -1105,15 +1111,13 @@ afs_CacheFetchProc(struct afs_conn *tc, struct rx_connection *rxconn,
      * adc->lock(W)
      */
     code = rxfs_fetchInit(
-	tc, rxconn, avc, base, size, &length, adc, fP, &ops, &rock);
+		tc, rxconn, avc, base, size, &length, adc, fP, &ops, &rock);
 
 #ifndef AFS_NOSTATS
     osi_GetuTime(&xferStartTime);
 #endif /* AFS_NOSTATS */
 
-    if (adc) {
-	adc->validPos = base;
-    }
+    adc->validPos = base;
 
     if ( !code ) do {
 	if (avc->f.states & CForeign) {
@@ -1165,7 +1169,7 @@ afs_CacheFetchProc(struct afs_conn *tc, struct rx_connection *rxconn,
 	(*ops->destroy)(&rock, code);
 
 #ifndef AFS_NOSTATS
-    FillStoreStats(code, AFS_STATS_FS_XFERIDX_FETCHDATA, &xferStartTime,
+    FillStoreStats(code, AFS_STATS_FS_XFERIDX_FETCHDATA, xferStartTime,
 			bytesToXfer, bytesXferred);
 #endif
     XSTATS_END_TIME;
