@@ -869,6 +869,9 @@ struct afs_stats_CMPerf {
 
 #define AFS_STATS_NUM_FS_RPC_OPS		29
 
+#define AFS_STATS_FS_RPCIDXES_ISWRITE(X)        (((X > AFS_STATS_FS_RPCIDX_FETCHSTATUS) && (X < AFS_STATS_FS_RPCIDX_GETSTATISTICS)) || (X == AFS_STATS_FS_RPCIDX_SETVOLUMESTATUS))
+#define AFS_STATS_FS_RPCIDXES_WRITE_RETRIABLE(X) ((X >= AFS_STATS_FS_RPCIDX_STOREDATA) && (X <= AFS_STATS_FS_RPCIDX_STORESTATUS))
+
 #define AFS_STATS_FS_XFERIDX_FETCHDATA		 0
 #define AFS_STATS_FS_XFERIDX_STOREDATA		 1
 
