@@ -264,11 +264,10 @@ dataBlock(usd_handle_t hTape, afs_int32 reqSize)
     }
 
     if (dB_buffer == 0) {
-	dB_buffer = (char *)malloc(reqSize);
+	dB_buffer = calloc(1, reqSize);
 	if (dB_buffer == 0)
 	    ERROR(-1);
 	dB_buffersize = reqSize;
-	memset(dB_buffer, 0, dB_buffersize);
     }
 
     ptr = (int *)dB_buffer;
