@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -10,24 +10,20 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#include <sys/types.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <netinet/in.h>
+#include <roken.h>
+
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif
-#include <fcntl.h>
-#include <errno.h>
+
 #include <limits.h>
-#include <sys/stat.h>
-#include <stdio.h>
-#include <string.h>
 #include <ctype.h>
+
 #include <lwp.h>
 #include <afs/com_err.h>
 #include <afs/butm.h>
 #include <afs/usd.h>
+
 #include "error_macros.h"
 #include "butm_prototypes.h"
 
@@ -77,9 +73,9 @@ extern int isafile;
  * blockMark contains a magic number and counts of real data bytes
  * written out in the block.
  *
- * each file is preceeded by a fileMark, which acts as the file 
+ * each file is preceeded by a fileMark, which acts as the file
  * delimiter. A file consists of contigous data blocks. TM does
- * understand or interrpet the data in data blocks. 
+ * understand or interrpet the data in data blocks.
  *
  * The tape begins with a tape label and ends with EOF file markers
  * in succession (2 or 4 of them ).
@@ -130,9 +126,9 @@ char tapeBlock[BUTM_BLOCKSIZE];	/* Tape buffer for reads and writes */
 
 /* ----------------------------------------------------------------------
  * These routines use the usd library to perform tape operations.
- * ForkIoctl, ForkOpen, ForkClose, ForwardSpace, BackwardSpace, WriteEOF, 
+ * ForkIoctl, ForkOpen, ForkClose, ForwardSpace, BackwardSpace, WriteEOF,
  * PrepareAccess(nt), ShutdownAccess(nt)
- * 
+ *
  * Return Values: USD functions return 0 if successful or errno if failed.
  */
 /* ------------------ USD Interface Functions Begin ------------------------ */
@@ -577,13 +573,12 @@ static int
 Rewind(usd_handle_t fid)
 {
     if (isafile) {
-	afs_hyper_t startOff, stopOff;
-	hzero(startOff);
+	afs_int64 stopOff;
 
-	return (USD_SEEK(fid, startOff, SEEK_SET, &stopOff));
+	return (USD_SEEK(fid, 0, SEEK_SET, &stopOff));
     } else {
 	return (ForkIoctl(fid, USDTAPE_REW, 0));
-    };
+    }
 }
 
 /* prepare tape drive for access */
@@ -639,7 +634,7 @@ incSize(struct butm_tapeInfo *info, afs_uint32 dataSize)
  *      TO ALSO MAKE THE SAME CHANGES IN bu_utils/fms.c.
  *
  *	add the supplied no. of bytes to the byte count of data placed
- *	on the tape. Also check for reaching 2GB limit and reset the 
+ *	on the tape. Also check for reaching 2GB limit and reset the
  *      pointer if necessary.  This allows us to use >2GB tapes.
  * entry:
  *      fid      - file id for the tape.
@@ -658,8 +653,9 @@ incPosition(struct butm_tapeInfo *info, usd_handle_t fid, afs_uint32 dataSize)
 	info->posCount = 0;
 #if (defined(AFS_SUN_ENV) || defined(AFS_LINUX24_ENV))
 	if (!isafile) {
-        afs_hyper_t off;
-	    hset64(off, 0, 0);
+	    afs_int64 off;
+
+	    off = 0;
 	    USD_IOCTL(fid, USD_IOCTL_SETSIZE, &off);
 	}
 #endif
@@ -667,7 +663,7 @@ incPosition(struct butm_tapeInfo *info, usd_handle_t fid, afs_uint32 dataSize)
 }
 
 /*
- * This accounts for tape drives with a block size different from variable or 16K 
+ * This accounts for tape drives with a block size different from variable or 16K
  * blocks and only reads that block size.
  */
 afs_int32 TapeBlockSize;
@@ -769,7 +765,7 @@ NextFile(struct butm_tapeInfo *info)
 }
 
 static afs_int32
-WriteTapeBlock(struct butm_tapeInfo *info, 
+WriteTapeBlock(struct butm_tapeInfo *info,
 	       char *buffer,     /* assumed to be 16384 bytes with data in it */
 	       afs_int32 length, /* amount data in buffer */
 	       afs_int32 blockType)
@@ -853,7 +849,7 @@ WriteTapeBlock(struct butm_tapeInfo *info,
 }
 
 static afs_int32
-ReadTapeBlock(struct butm_tapeInfo *info, 
+ReadTapeBlock(struct butm_tapeInfo *info,
 	      char *buffer, /* assumed to be 16384 bytes */
 	      afs_int32 *blockType)
 {
@@ -928,7 +924,7 @@ ReadTapeBlock(struct butm_tapeInfo *info,
  */
 
 static afs_int32
-check(struct butm_tapeInfo *info, 
+check(struct butm_tapeInfo *info,
       int write) /* write operation requested */
 {
     struct progress *p;
@@ -1056,7 +1052,7 @@ file_Mount(struct butm_tapeInfo *info, char *tape)
 
     (void)PrepareAccess(fid);	/* for NT */
 
-    p = (struct progress *)malloc(sizeof(*p));
+    p = malloc(sizeof(*p));
     info->tmRock = (char *)p;
     p->fid = fid;
     p->mountId = config.mountId = time(0);
@@ -1123,14 +1119,14 @@ file_Dismount(struct butm_tapeInfo *info)
  */
 
 static afs_int32
-file_WriteLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label, 
+file_WriteLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label,
 		afs_int32 rewind)
 {
     afs_int32 code = 0;
     afs_int32 fcode;
     struct tapeLabel *tlabel;
     struct progress *p;
-    afs_hyper_t off;		/* offset */
+    afs_int64 off;		/* offset */
 
     if (info->debug)
 	printf("butm: Write tape label\n");
@@ -1153,7 +1149,7 @@ file_WriteLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label,
 
 	if (isafile) {
 	    p = (struct progress *)info->tmRock;
-	    hset64(off, 0, 0);
+	    off = 0;
 	    code = USD_IOCTL(p->fid, USD_IOCTL_SETSIZE, &off);
 	    if (code)
 		ERROR_EXIT(BUTM_POSITION);
@@ -1179,9 +1175,9 @@ file_WriteLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label,
     tlabel->label.useCount = htonl(tlabel->label.useCount);
     tlabel->label.dumpid = htonl(tlabel->label.dumpid);
 
-    /* 
-     * write the tape label - For appends, the write may need to skip 
-     * over 1 or 2 EOF marks that were written when tape was closed after 
+    /*
+     * write the tape label - For appends, the write may need to skip
+     * over 1 or 2 EOF marks that were written when tape was closed after
      * the last dump. Plus, some AIX tape drives require we try forwarding
      * over the last EOF and take an error before we can write the new label.
      * ---------------------------------------------------------------------- */
@@ -1229,7 +1225,7 @@ file_WriteLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label,
 }
 
 static afs_int32
-file_ReadLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label, 
+file_ReadLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label,
 	       afs_int32 rewind)
 {
     struct tapeLabel *tlabel;
@@ -1256,7 +1252,7 @@ file_ReadLabel(struct butm_tapeInfo *info, struct butm_tapeLabel *label,
 
     /*
      * When appended labels were written, either 1 or 2 EOF marks may
-     * have had to be skipped.  When reading a label, these EOF marks 
+     * have had to be skipped.  When reading a label, these EOF marks
      * must also be skipped. When an EOF is read, 0 bytes are returned
      * (refer to the write calls in file_WriteLabel routine).
      * ---------------------------------------------------------------- */
@@ -1487,8 +1483,8 @@ file_WriteFileEnd(struct butm_tapeInfo *info)
     return (code);
 }
 
-/* Read a SW filemark, verify that it is a SW filemark, then skip to the next 
- * HW filemark. If the read of the SW filemark shows it's an EOF, then 
+/* Read a SW filemark, verify that it is a SW filemark, then skip to the next
+ * HW filemark. If the read of the SW filemark shows it's an EOF, then
  * ignore that the SW filemark is not there and return 0 (found the SW filemark
  * missing with some 3.1 dumps).
  */
@@ -1559,9 +1555,8 @@ file_Seek(struct butm_tapeInfo *info, afs_int32 position)
     afs_int32 code = 0;
     afs_int32 w;
     osi_lloff_t posit;
-    afs_uint32 c, d;
     struct progress *p;
-    afs_hyper_t startOff, stopOff;	/* for normal file(non-tape)  seeks  */
+    afs_int64 stopOff;	/* for normal file(non-tape)  seeks  */
 
     if (info->debug)
 	printf("butm: Seek to the tape position %d\n", position);
@@ -1576,20 +1571,10 @@ file_Seek(struct butm_tapeInfo *info, afs_int32 position)
 	p = (struct progress *)info->tmRock;
 	posit = (osi_lloff_t) position *(osi_lloff_t) BUTM_BLOCKSIZE;
 
-	/* Not really necessary to do it this way, should be fixed */
-#ifdef O_LARGEFILE
-	c = (posit >> 32);
-	d = (posit & 0xffffffff);
-#else
-	c = 0;
-	d = posit;
-#endif
-	hset64(startOff, c, d);
-
-	w = USD_SEEK(p->fid, startOff, SEEK_SET, &stopOff);
+	w = USD_SEEK(p->fid, posit, SEEK_SET, &stopOff);
 	if (w)
 	    info->error = w;
-	if (hcmp(startOff, stopOff) != 0)
+	if (posit != stopOff)
 	    ERROR_EXIT(BUTM_POSITION);
 
 	p->reading = p->writing = 0;
@@ -1609,8 +1594,8 @@ file_Seek(struct butm_tapeInfo *info, afs_int32 position)
 }
 
 /*
- * Seek to the EODump (end-of-dump) after the given position. This is 
- * the position after the EOF filemark immediately after the EODump mark. 
+ * Seek to the EODump (end-of-dump) after the given position. This is
+ * the position after the EOF filemark immediately after the EODump mark.
  * This is for tapes of version 4 or greater.
  */
 static afs_int32
@@ -1620,7 +1605,7 @@ file_SeekEODump(struct butm_tapeInfo *info, afs_int32 position)
     afs_int32 blockType;
     afs_int32 w;
     struct progress *p;
-    afs_hyper_t startOff, stopOff;	/* file seek offsets */
+    afs_int64 stopOff;	/* file seek offsets */
 
     if (info->debug)
 	printf("butm: Seek to end-of-dump\n");
@@ -1634,16 +1619,15 @@ file_SeekEODump(struct butm_tapeInfo *info, afs_int32 position)
 
     if (isafile) {
 	p = (struct progress *)info->tmRock;
-	hset64(startOff, 0, 0);
-	w = USD_SEEK(p->fid, startOff, SEEK_END, &stopOff);
+	w = USD_SEEK(p->fid, 0, SEEK_END, &stopOff);
 	if (w) {
 	    info->error = w;
 	    ERROR_EXIT(BUTM_POSITION);
 	}
 
-	if (hgetlo(stopOff) % BUTM_BLOCKSIZE)
+	if (stopOff % BUTM_BLOCKSIZE)
 	    ERROR_EXIT(BUTM_POSITION);
-	info->position = (hgetlo(stopOff) / BUTM_BLOCKSIZE);
+	info->position = (stopOff / BUTM_BLOCKSIZE);
     } else {
 	/* Seek to the desired position */
 	code = SeekFile(info, (position - info->position) + 1);
