@@ -128,7 +128,7 @@ xdr_CBS(XDR * x, struct CBS * abbs)
 	    return FALSE;
 	}
 	if (!abbs->SeqBody)
-	    abbs->SeqBody = (char *)NVALLOC(len);
+	    abbs->SeqBody = NVALLOC(len);
 	abbs->SeqLen = len;
 	xdr_opaque(x, abbs->SeqBody, len);
 	return TRUE;
@@ -157,7 +157,7 @@ xdr_BBS(XDR * x, struct BBS * abbs)
 	    return FALSE;
 	}
 	if (!abbs->SeqBody)
-	    abbs->SeqBody = (char *)NVALLOC(maxLen);
+	    abbs->SeqBody = NVALLOC(maxLen);
 	abbs->MaxSeqLen = maxLen;
 	abbs->SeqLen = len;
 	xdr_opaque(x, abbs->SeqBody, len);
@@ -187,7 +187,7 @@ xdr_AFSAccessList(XDR * x, AFSAccessList * abbs)
 	    return FALSE;
 	}
 	if (!abbs->SeqBody)
-	    abbs->SeqBody = (char *)NVALLOC(maxLen);
+	    abbs->SeqBody = NVALLOC(maxLen);
 	abbs->MaxSeqLen = maxLen;
 	abbs->SeqLen = len;
 	xdr_opaque(x, abbs->SeqBody, len);
