@@ -17,6 +17,7 @@
 #include <ubik.h>
 #include <afs/cmd.h>
 #include <rx/rxkad.h>
+#include <rx/rxkad_convert.h>
 #include <afs/com_err.h>
 
 #include "kauth.h"
@@ -55,7 +56,7 @@ readUbikHeader(void)
     }
 
     uheader.magic = ntohl(uheader.magic);
-    uheader.size = ntohl(uheader.size);
+    uheader.size = ntohs(uheader.size);
     uheader.version.epoch = ntohl(uheader.version.epoch);
     uheader.version.counter = ntohl(uheader.version.counter);
 
@@ -435,8 +436,7 @@ WorkerBee(struct cmd_syndesc *as, void *arock)
     nentries =
 	(info.st_size -
 	 (UBIK_HEADERSIZE + header.headerSize)) / sizeof(struct kaentry);
-    entrys = (int *)malloc(nentries * sizeof(int));
-    memset(entrys, 0, nentries * sizeof(int));
+    entrys = calloc(nentries, sizeof(int));
 
     for (i = 0, index = sizeof(header); i < nentries;
 	 i++, index += sizeof(struct kaentry)) {
