@@ -17,17 +17,10 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/cfg/cfgservers.c,v 1.6.14.2 2009/03/16 13:26:50 shadow Exp $");
-
 #include <afs/stds.h>
 
-#include <stddef.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <errno.h>
-#include <string.h>
+#include <roken.h>
+
 #include <ctype.h>
 
 #ifdef AFS_NT40_ENV
@@ -1188,7 +1181,7 @@ cfg_UpdateServerStart(void *hostHandle,	/* host config handle */
 	    if (argsLen <= AFSDIR_PATH_MAX) {
 		args = argsBuf;
 	    } else {
-		args = (char *)malloc(argsLen);
+		args = malloc(argsLen);
 	    }
 
 	    if (args == NULL) {
@@ -1451,7 +1444,7 @@ cfg_UpdateClientStart(void *hostHandle,	/* host config handle */
 	if (argsLen <= AFSDIR_PATH_MAX) {
 	    args = argsBuf;
 	} else {
-	    args = (char *)malloc(argsLen);
+	    args = malloc(argsLen);
 	}
 
 	if (args == NULL) {
@@ -1782,7 +1775,7 @@ SimpleProcessStart(void *bosHandle, const char *instance,
     if (cmdLen <= AFSDIR_PATH_MAX) {
 	cmd = cmdBuf;
     } else {
-	cmd = (char *)malloc(cmdLen);
+	cmd = malloc(cmdLen);
     }
 
     if (cmd == NULL) {
@@ -1795,13 +1788,13 @@ SimpleProcessStart(void *bosHandle, const char *instance,
 	}
 
 	if (!bos_ProcessCreate
-	    (bosHandle, instance, BOS_PROCESS_SIMPLE, cmd, NULL, NULL, &tst2)
+	    (bosHandle, (char *)instance, BOS_PROCESS_SIMPLE, cmd, NULL, NULL, &tst2)
 	    && tst2 != BZEXISTS) {
 	    /* failed to create instance (and not because existed) */
 	    tst = tst2;
 	} else
 	    if (!bos_ProcessExecutionStateSet
-		(bosHandle, instance, BOS_PROCESS_RUNNING, &tst2)) {
+		(bosHandle, (char *)instance, BOS_PROCESS_RUNNING, &tst2)) {
 	    /* failed to set instance state to running */
 	    tst = tst2;
 	}
@@ -1837,7 +1830,7 @@ FsProcessStart(void *bosHandle, const char *instance,
     afs_status_t tst2, tst = 0;
 
     if (!bos_FSProcessCreate
-	(bosHandle, instance, fileserverExe, volserverExe, salvagerExe, NULL,
+	(bosHandle, (char *)instance, (char *)fileserverExe, (char *)volserverExe, (char *)salvagerExe, NULL,
 	 &tst2) && tst2 != BZEXISTS) {
 	/* failed to create instance (and not because existed) */
 	tst = tst2;
@@ -1882,7 +1875,7 @@ BosProcessDelete(void *bosHandle, const char *instance, afs_status_p st)
 	/* failed to wait for process to stop */
 	tst = tst2;
 
-    } else if (!bos_ProcessDelete(bosHandle, instance, &tst2)) {
+    } else if (!bos_ProcessDelete(bosHandle, (char *)instance, &tst2)) {
 	/* failed to delete instance (or does not exist) */
 	if (tst2 != BZNOENT) {
 	    tst = tst2;
@@ -2108,7 +2101,6 @@ UbikVoteStatusFetch(int serverAddr, unsigned short serverPort,
     } else {
 	int rpcCode;
 	struct ubik_debug udebugInfo;
-	extern int VOTE_Debug(), VOTE_DebugOld();
 
 	if ((rpcCode = VOTE_Debug(serverConn, &udebugInfo)) == 0) {
 	    /* talking to a 3.5 or later server */
@@ -2116,7 +2108,7 @@ UbikVoteStatusFetch(int serverAddr, unsigned short serverPort,
 	    *isWriteReady = 0;
 
 	    if (*isSyncSite) {
-		/* as of 3.5 the database is writeable if "labeled" or if all
+		/* as of 3.5 the database is writable if "labeled" or if all
 		 * prior recovery states have been achieved; see defect 9477.
 		 */
 		if (((udebugInfo.recoveryState & UBIK_RECLABELDB))
@@ -2136,7 +2128,7 @@ UbikVoteStatusFetch(int serverAddr, unsigned short serverPort,
 		*isWriteReady = 0;
 
 		if (*isSyncSite) {
-		    /* pre 3.5 the database is writeable only if "labeled" */
+		    /* pre 3.5 the database is writable only if "labeled" */
 		    if (udebugInfo.recoveryState & UBIK_RECLABELDB) {
 			*isWriteReady = 1;
 		    }
