@@ -9,36 +9,23 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-
 #include <afs/stds.h>
-#include "afs_clientAdmin.h"
-#include "../adminutil/afs_AdminInternal.h"
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <afs/cellconfig.h>
+
+#include <roken.h>
+
 #ifdef AFS_NT40_ENV
 #include <afs/afssyscalls.h>
-#include <winsock2.h>
 #include <afs/fs_utils.h>
 #define close(x) closesocket(x)
 #else
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
 #include <afs/venus.h>
-#include <errno.h>
-#include <strings.h>
-#include <unistd.h>
 #endif
-#include <string.h>
-#include <afs/kautils.h>
 #include <rx/rx.h>
 #include <rx/rxstat.h>
 #include <rx/rx_null.h>
 #include <rx/rxkad.h>
+
+#include <afs/kautils.h>
 #include <afs/dirpath.h>
 #include <afs/afs_AdminErrors.h>
 #include <afs/afs_vosAdmin.h>
@@ -48,6 +35,9 @@
 #include <afs/pthread_glock.h>
 #include <afs/sys_prototypes.h>
 
+#include "afs_clientAdmin.h"
+#include "../adminutil/afs_AdminInternal.h"
+
 /*
  * AFS client administration functions.
  *
@@ -1445,9 +1435,6 @@ afsclient_ACLEntryAdd(const char *directory, const char *user,
     char tmp[64 + 35];
     int is_dfs;
 
-    memset(&cur_acl, 0, sizeof(cur_acl));
-    memset(cur_user, 0, sizeof(cur_user));
-
     if (client_init == 0) {
 	tst = ADMCLIENTNOINIT;
 	goto fail_afsclient_ACLEntryAdd;
@@ -1545,16 +1532,12 @@ afsclient_ACLEntryAdd(const char *directory, const char *user,
      */
 
     is_dfs =
-	sscanf(old_acl_string, "%d dfs:%d %1024s", &cur_acl.nplus, &cur_acl.dfs,
+	sscanf(old_acl_string, "%d dfs:%d %s", &cur_acl.nplus, &cur_acl.dfs,
 	       cur_acl.cell);
     ptr = strchr(old_acl_string, '\n');
-    if (ptr == NULL)
-	goto fail_afsclient_ACLEntryAdd;
     ptr++;
     sscanf(ptr, "%d", &cur_acl.nminus);
     ptr = strchr(ptr, '\n');
-    if (ptr == NULL)
-	goto fail_afsclient_ACLEntryAdd;
     ptr++;
     if (is_dfs == 3) {
 	tst = ADMMISCNODFSACL;
@@ -1574,15 +1557,13 @@ afsclient_ACLEntryAdd(const char *directory, const char *user,
      */
 
     for (i = 0; i < (cur_acl.nplus + cur_acl.nminus); i++) {
-	sscanf(ptr, "%63s%d\n", cur_user, &cur_user_acl);
+	sscanf(ptr, "%s%d\n", cur_user, &cur_user_acl);
 	/*
 	 * Skip the entry for the user we are replacing/adding
 	 */
 
 	if (strcmp(cur_user, user)) {
 	    ptr = strchr(ptr, '\n');
-	    if (ptr == NULL)
-		goto fail_afsclient_ACLEntryAdd;
 	    ptr++;
 	    sprintf(tmp, "%s %d\n", cur_user, cur_user_acl);
 	    strcat(new_acl_string, tmp);
@@ -1841,9 +1822,8 @@ afsclient_AFSServerGetBegin(const void *cellHandle, void **iterationIdP,
     int rc = 0;
     afs_status_t tst = 0;
     afs_cell_handle_p c_handle = (afs_cell_handle_p) cellHandle;
-    afs_admin_iterator_p iter =
-	(afs_admin_iterator_p) malloc(sizeof(afs_admin_iterator_t));
-    server_get_p serv = (server_get_p) calloc(1, sizeof(server_get_t));
+    afs_admin_iterator_p iter = malloc(sizeof(afs_admin_iterator_t));
+    server_get_p serv = calloc(1, sizeof(server_get_t));
     server_get_p serv_cache = NULL;
     const char *cellName = NULL;
     void *database_iter;
@@ -2673,7 +2653,7 @@ afsclient_RXDebugOpen(const char *serverName, afs_stat_source_t type,
 	goto fail_afsclient_RXDebugOpen;
     }
 
-    handle = (rxdebugHandle_p) malloc(sizeof(rxdebugHandle_t));
+    handle = malloc(sizeof(rxdebugHandle_t));
     if (!handle) {
 	close(sock);
 	tst = ADMNOMEM;
@@ -2758,7 +2738,7 @@ afsclient_RXDebugOpenPort(const char *serverName, int serverPort,
 	goto fail_afsclient_RXDebugOpenPort;
     }
 
-    handle = (rxdebugHandle_p) malloc(sizeof(rxdebugHandle_t));
+    handle = malloc(sizeof(rxdebugHandle_t));
     if (!handle) {
 	close(sock);
 	tst = ADMNOMEM;
