@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxkad/test/stress.c,v 1.9.14.2 2007/10/31 04:09:35 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -27,6 +25,8 @@ RCSID
 #include <lwp.h>
 #include <rx/xdr.h>
 #include <rx/rx.h>
+#include <afs/afsutil.h>
+#include <afs/auth.h>
 #include <afs/com_err.h>
 #include <afs/cmd.h>
 
@@ -44,8 +44,7 @@ int maxSkew = 5;
 static char *whoami;
 
 static int
-StringToAuth(authname)
-     IN char *authname;
+StringToAuth(const char *authname)
 {
     int nonoauth = 0;
     if (strcmp(authname, "rxkad") == 0)
@@ -115,8 +114,8 @@ CommandProc(struct cmd_syndesc *as, void *arock)
     struct serverParms *sParms;
     struct clientParms *cParms;
 
-    sParms = (struct serverParms *)osi_Alloc(sizeof(*sParms));
-    cParms = (struct clientParms *)osi_Alloc(sizeof(*cParms));
+    sParms = osi_Alloc(sizeof(*sParms));
+    cParms = osi_Alloc(sizeof(*cParms));
     memset(sParms, 0, sizeof(*sParms));
     memset(cParms, 0, sizeof(*cParms));
     sParms->whoami = cParms->whoami = whoami;
@@ -270,16 +269,14 @@ CommandProc(struct cmd_syndesc *as, void *arock)
 	}
 
 	/* donate this LWP to server-side */
-	rx_ServerProc();
+	rx_ServerProc(NULL);
     }
 
     return 0;
 }
 
-void
-main(argc, argv)
-     IN int argc;
-     IN char *argv[];
+int
+main(int argc, char **argv)
 {
     long code;
 #ifndef AFS_PTHREAD_ENV
