@@ -12,11 +12,19 @@
 
 #include <roken.h>
 
+
+#include <afs/opr.h>
+#ifdef AFS_PTHREAD_ENV
+# include <opr/lock.h>
+#else
+# include <opr/lockstub.h>
+#endif
+
 #include <lock.h>
-#include <rx/xdr.h>
 #include <rx/rx.h>
 #include <afs/cellconfig.h>
 
+
 #define UBIK_INTERNALS
 #include "ubik.h"
 #include "ubik_int.h"
@@ -355,9 +363,10 @@ ContactQuorum_DISK_SetVersion(struct ubik_trans *atrans, int aflags,
 #if defined(AFS_PTHREAD_ENV)
 static int
 ubik_thread_create(pthread_attr_t *tattr, pthread_t *thread, void *proc) {
-    osi_Assert(pthread_attr_init(tattr) == 0);
-    osi_Assert(pthread_attr_setdetachstate(tattr, PTHREAD_CREATE_DETACHED) == 0);
-    osi_Assert(pthread_create(thread, tattr, proc, NULL) == 0);
+    opr_Verify(pthread_attr_init(tattr) == 0);
+    opr_Verify(pthread_attr_setdetachstate(tattr,
+					   PTHREAD_CREATE_DETACHED) == 0);
+    opr_Verify(pthread_create(thread, tattr, proc, NULL) == 0);
     return 0;
 }
 #endif
@@ -403,18 +412,17 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
 
     initialize_U_error_table();
 
-    tdb = (struct ubik_dbase *)malloc(sizeof(struct ubik_dbase));
-    tdb->pathName = (char *)malloc(strlen(pathName) + 1);
-    strcpy(tdb->pathName, pathName);
+    tdb = malloc(sizeof(struct ubik_dbase));
+    tdb->pathName = strdup(pathName);
     tdb->activeTrans = (struct ubik_trans *)0;
     memset(&tdb->version, 0, sizeof(struct ubik_version));
     memset(&tdb->cachedVersion, 0, sizeof(struct ubik_version));
 #ifdef AFS_PTHREAD_ENV
-    MUTEX_INIT(&tdb->versionLock, "version lock", MUTEX_DEFAULT, 0);
-    MUTEX_INIT(&beacon_globals.beacon_lock, "beacon lock", MUTEX_DEFAULT, 0);
-    MUTEX_INIT(&vote_globals.vote_lock, "vote lock", MUTEX_DEFAULT, 0);
-    MUTEX_INIT(&addr_globals.addr_lock, "address lock", MUTEX_DEFAULT, 0);
-    MUTEX_INIT(&version_globals.version_lock, "version lock", MUTEX_DEFAULT, 0);
+    opr_mutex_init(&tdb->versionLock);
+    opr_mutex_init(&beacon_globals.beacon_lock);
+    opr_mutex_init(&vote_globals.vote_lock);
+    opr_mutex_init(&addr_globals.addr_lock);
+    opr_mutex_init(&version_globals.version_lock);
 #else
     Lock_Init(&tdb->versionLock);
 #endif
@@ -435,8 +443,8 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
     ubik_dbase = tdb;		/* for now, only one db per server; can fix later when we have names for the other dbases */
 
 #ifdef AFS_PTHREAD_ENV
-    CV_INIT(&tdb->version_cond, "version", CV_DEFAULT, 0);
-    CV_INIT(&tdb->flags_cond, "flags", CV_DEFAULT, 0);
+    opr_cv_init(&tdb->version_cond);
+    opr_cv_init(&tdb->flags_cond);
 #endif /* AFS_PTHREAD_ENV */
 
     /* initialize RX */
@@ -447,6 +455,8 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
     if (code < 0)
 	return code;
 
+    ubik_callPortal = myPort;
+
     udisk_Init(ubik_nBuffers);
     ulock_Init();
 
@@ -463,7 +473,6 @@ ubik_ServerInitCommon(afs_uint32 myHost, short myPort,
     if (code)
 	return code;
 
-    ubik_callPortal = myPort;
     /* try to get an additional security object */
     if (buildSecClassesProc == NULL) {
 	numClasses = 3;
@@ -623,7 +632,7 @@ BeginTrans(struct ubik_dbase *dbase, afs_int32 transMode,
 	/* if we're writing already, wait */
 	while (dbase->flags & DBWRITING) {
 #ifdef AFS_PTHREAD_ENV
-	    CV_WAIT(&dbase->flags_cond, &dbase->versionLock);
+	    opr_cv_wait(&dbase->flags_cond, &dbase->versionLock);
 #else
 	    DBRELE(dbase);
 	    LWP_WaitProcess(&dbase->flags);
@@ -640,7 +649,7 @@ BeginTrans(struct ubik_dbase *dbase, afs_int32 transMode,
     /* create the transaction */
     code = udisk_begin(dbase, transMode, &jt);	/* can't take address of register var */
     tt = jt;			/* move to a register */
-    if (code || tt == (struct ubik_trans *)NULL) {
+    if (code || tt == NULL) {
 	DBRELE(dbase);
 	return code;
     }
@@ -1049,10 +1058,9 @@ ubik_Write(struct ubik_trans *transPtr, void *vbuffer,
     if (!transPtr->iovec_info.iovec_wrt_val) {
 	transPtr->iovec_info.iovec_wrt_len = 0;
 	transPtr->iovec_info.iovec_wrt_val =
-	    (struct ubik_iovec *)malloc(IOVEC_MAXWRT *
-					sizeof(struct ubik_iovec));
+	    malloc(IOVEC_MAXWRT * sizeof(struct ubik_iovec));
 	transPtr->iovec_data.iovec_buf_len = 0;
-	transPtr->iovec_data.iovec_buf_val = (char *)malloc(IOVEC_MAXBUF);
+	transPtr->iovec_data.iovec_buf_val = malloc(IOVEC_MAXBUF);
 	if (!transPtr->iovec_info.iovec_wrt_val
 	    || !transPtr->iovec_data.iovec_buf_val) {
 	    if (transPtr->iovec_info.iovec_wrt_val)
@@ -1255,7 +1263,7 @@ ubik_WaitVersion(struct ubik_dbase *adatabase,
 	    return 0;
 	}
 #ifdef AFS_PTHREAD_ENV
-	CV_WAIT(&adatabase->version_cond, &adatabase->versionLock);
+	opr_cv_wait(&adatabase->version_cond, &adatabase->versionLock);
 #else
 	DBRELE(adatabase);
 	LWP_WaitProcess(&adatabase->version);	/* same vers, just wait */
