@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -12,23 +12,10 @@
  */
 #include <afsconfig.h>
 #include <afs/param.h>
-
-
-#include <stdio.h>
-#include <sys/types.h>
-#include <unistd.h>
-#if !defined(AFS_SUN3_ENV) && !defined(sys_vax_ul43) 
-#include <time.h>
-/*#ifdef	AFS_AIX_ENV*/
-#include <sys/time.h>
-/*#endif*/
-#include <errno.h>
-#undef abs
-#include <stdlib.h>
-
-#include <string.h>
-
 #include <afs/stds.h>
+
+#include <roken.h>
+
 #include <afs/cmd.h>
 #include <afs/afs_args.h>
 #include <afs/icl.h>
@@ -48,7 +35,6 @@ int afs_icl_sizeofLong = 1;
 int afs_64bit_kernel = 1;	/* Default for 6.2+, and always for 6.1 */
 extern int afs_icl_sizeofLong;	/* Used in ICL_SIZEHACK() */
 #ifdef AFS_SGI62_ENV
-#include <unistd.h>
 
 /* If _SC_KERN_POINTERS not in sysconf, then we can assume a 32 bit abi. */
 void
@@ -77,12 +63,12 @@ void dce1_error_inq_text(afs_uint32 status_to_convert,
 int icl_CreateSetWithFlags(char *name, struct afs_icl_log *baseLogp,
 		           struct afs_icl_log *fatalLogp, afs_uint32 flags,
 		           struct afs_icl_set **outSetpp);
-int icl_LogHold(register struct afs_icl_log *logp);
-int icl_LogUse(register struct afs_icl_log *logp);
-int icl_LogReleNL(register struct afs_icl_log *logp);
-int icl_LogRele(register struct afs_icl_log *logp);
-int icl_ZeroLog(register struct afs_icl_log *logp);
-int icl_LogFreeUse(register struct afs_icl_log *logp);
+int icl_LogHold(struct afs_icl_log *logp);
+int icl_LogUse(struct afs_icl_log *logp);
+int icl_LogReleNL(struct afs_icl_log *logp);
+int icl_LogRele(struct afs_icl_log *logp);
+int icl_ZeroLog(struct afs_icl_log *logp);
+int icl_LogFreeUse(struct afs_icl_log *logp);
 
 #define BUFFER_MULTIPLIER     1024
 
@@ -134,7 +120,7 @@ icl_GetSize(afs_int32 type, char *addr)
 static int
 CheckTypes(char *bufferp, int *typesp, int typeCount, char *outMsgBuffer)
 {
-    register char tc;
+    char tc;
     int inPercent;
     int tix;
 
@@ -209,7 +195,7 @@ CheckTypes(char *bufferp, int *typesp, int typeCount, char *outMsgBuffer)
 static int
 CheckTypes(char *bufferp, int *typesp, int typeCount)
 {
-    register char tc;
+    char tc;
     int inPercent;
     int tix;
 
@@ -260,7 +246,7 @@ CheckTypes(char *bufferp, int *typesp, int typeCount)
 #define uint64_t long long
 #endif
 static void
-DisplayRecord(FILE *outFilep, register afs_int32 *alp, afs_int32 rsize)
+DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 {
     char msgBuffer[1024];
 #if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
@@ -548,7 +534,7 @@ DisplayRecord(FILE *outFilep, register afs_int32 *alp, afs_int32 rsize)
  */
 
 void
-dce1_error_inq_text(afs_uint32 status_to_convert, 
+dce1_error_inq_text(afs_uint32 status_to_convert,
 		   char *error_text, int *status)
 {
     unsigned short facility_code;
@@ -622,8 +608,8 @@ dce1_error_inq_text(afs_uint32 status_to_convert,
      * install this special message catalog in with internationalization
      * catalogs.
      */
-    afs_snprintf(nls_filename, sizeof(nls_filename), "%s/C/%s.cat",
-		 AFSDIR_CLIENT_DATA_DIRPATH, filename_prefix);
+    snprintf(nls_filename, sizeof(nls_filename), "%s/C/%s.cat",
+	     AFSDIR_CLIENT_DATA_DIRPATH, filename_prefix);
 
     catd = catopen(nls_filename, 0);
     if (catd == (nl_catd) -1) {
@@ -688,12 +674,10 @@ icl_DumpKernel(FILE *outFilep, char *setname)
 	    found++;
 	    if (dummy > bufferSize)	/* find biggest log */
 		bufferSize = dummy;
-	    lip = (struct logInfo *)malloc(sizeof(struct logInfo));
-	    memset(lip, 0, sizeof(*lip));
+	    lip = calloc(1, sizeof(struct logInfo));
 	    lip->nextp = allInfo;
 	    allInfo = lip;
-	    lip->name = (char *)malloc(strlen(tname) + 1);
-	    strcpy(lip->name, tname);
+	    lip->name = strdup(tname);
 	}
 	i = found;
     } else {
@@ -706,18 +690,16 @@ icl_DumpKernel(FILE *outFilep, char *setname)
 		break;
 	    if (dummy > bufferSize)	/* find biggest log */
 		bufferSize = dummy;
-	    lip = (struct logInfo *)malloc(sizeof(struct logInfo));
-	    memset(lip, 0, sizeof(*lip));
+	    lip = calloc(1, sizeof(struct logInfo));
 	    lip->nextp = allInfo;
 	    allInfo = lip;
-	    lip->name = (char *)malloc(strlen(tname) + 1);
-	    strcpy(lip->name, tname);
+	    lip->name = strdup(tname);
 	}
     }
 
     if (bufferSize == 0)
 	return -1;
-    bufferp = (afs_int32 *) malloc(sizeof(afs_int32) * bufferSize);
+    bufferp = malloc(sizeof(afs_int32) * bufferSize);
     if (!bufferp)
 	return -1;
 
@@ -1003,7 +985,7 @@ icl_TailKernel(FILE *outFilep, char *logname, afs_int32 waitTime)
 
     if (bufferSize == 0)
 	return -1;
-    bufferp = (afs_int32 *) malloc(sizeof(afs_int32) * bufferSize);
+    bufferp = malloc(sizeof(afs_int32) * bufferSize);
     if (!bufferp) {
 	(void)fprintf(stderr, "cannot allocate %d words for buffer\n",
 		      bufferSize);
@@ -1097,7 +1079,7 @@ icl_TailKernel(FILE *outFilep, char *logname, afs_int32 waitTime)
 	    /* have to reallocate a buffer */
 	    bufferSize = newBufferSize;
 	    free(bufferp);
-	    bufferp = (afs_int32 *) malloc(sizeof(afs_int32) * bufferSize);
+	    bufferp = malloc(sizeof(afs_int32) * bufferSize);
 	    if (!bufferp) {
 		(void)fprintf(stderr, "cannot allocate %d words for buffer\n",
 			      bufferSize);
@@ -1114,7 +1096,7 @@ icl_TailKernel(FILE *outFilep, char *logname, afs_int32 waitTime)
 
 #if !defined(AFS_SGI_ENV)
 int
-afs_syscall(long call, long parm0, long parm1, long parm2, long parm3, 
+afs_syscall(long call, long parm0, long parm1, long parm2, long parm3,
 	    long parm4, long parm5, long parm6)
 {
     int code, rval;
@@ -1184,7 +1166,7 @@ icl_Init(void)
 }
 
 int
-icl_CreateSet(char *name, struct afs_icl_log *baseLogp, 
+icl_CreateSet(char *name, struct afs_icl_log *baseLogp,
 	      struct afs_icl_log *fatalLogp, struct afs_icl_set **outSetpp)
 {
     return icl_CreateSetWithFlags(name, baseLogp, fatalLogp, /*flags */ 0,
@@ -1198,12 +1180,12 @@ icl_CreateSet(char *name, struct afs_icl_log *baseLogp,
  * those references will be released.
  */
 int
-icl_CreateSetWithFlags(char *name, struct afs_icl_log *baseLogp, 
-		       struct afs_icl_log *fatalLogp, afs_uint32 flags, 
+icl_CreateSetWithFlags(char *name, struct afs_icl_log *baseLogp,
+		       struct afs_icl_log *fatalLogp, afs_uint32 flags,
 		       struct afs_icl_set **outSetpp)
 {
-    register struct afs_icl_set *setp;
-    register int i;
+    struct afs_icl_set *setp;
+    int i;
     afs_int32 states = ICL_DEFAULT_SET_STATES;
 
     if (!icl_inited)
@@ -1228,17 +1210,17 @@ icl_CreateSetWithFlags(char *name, struct afs_icl_log *baseLogp,
     if (flags & ICL_CRSET_FLAG_PERSISTENT)
 	states |= ICL_SETF_PERSISTENT;
 
-    setp = (struct afs_icl_set *)osi_Alloc(sizeof(struct afs_icl_set));
+    setp = osi_Alloc(sizeof(struct afs_icl_set));
     memset((caddr_t) setp, 0, sizeof(*setp));
     setp->refCount = 1;
     if (states & ICL_SETF_FREED)
 	states &= ~ICL_SETF_ACTIVE;	/* if freed, can't be active */
     setp->states = states;
 
-    setp->name = (char *)osi_Alloc(strlen(name) + 1);
+    setp->name = osi_Alloc(strlen(name) + 1);
     strcpy(setp->name, name);
     setp->nevents = ICL_DEFAULTEVENTS;
-    setp->eventFlags = (char *)osi_Alloc(ICL_DEFAULTEVENTS);
+    setp->eventFlags = osi_Alloc(ICL_DEFAULTEVENTS);
     for (i = 0; i < ICL_DEFAULTEVENTS; i++)
 	setp->eventFlags[i] = 0xff;	/* default to enabled */
 
@@ -1300,7 +1282,7 @@ icl_GetEnable(struct afs_icl_set *setp, afs_int32 eventID, int *getValuep)
 
 /* hold and release event sets */
 int
-icl_SetHold(register struct afs_icl_set *setp)
+icl_SetHold(struct afs_icl_set *setp)
 {
     setp->refCount++;
     return 0;
@@ -1308,11 +1290,11 @@ icl_SetHold(register struct afs_icl_set *setp)
 
 /* free a set.  Called with icl_lock locked */
 int
-icl_ZapSet(register struct afs_icl_set *setp)
+icl_ZapSet(struct afs_icl_set *setp)
 {
-    register struct afs_icl_set **lpp, *tp;
+    struct afs_icl_set **lpp, *tp;
     int i;
-    register struct afs_icl_log *tlp;
+    struct afs_icl_log *tlp;
 
     for (lpp = &icl_allSets, tp = *lpp; tp; lpp = &tp->nextp, tp = *lpp) {
 	if (tp == setp) {
@@ -1333,7 +1315,7 @@ icl_ZapSet(register struct afs_icl_set *setp)
 
 /* do the release, watching for deleted entries */
 int
-icl_SetRele(register struct afs_icl_set *setp)
+icl_SetRele(struct afs_icl_set *setp)
 {
     if (--setp->refCount == 0 && (setp->states & ICL_SETF_DELETED)) {
 	icl_ZapSet(setp);	/* destroys setp's lock! */
@@ -1343,7 +1325,7 @@ icl_SetRele(register struct afs_icl_set *setp)
 
 /* free a set entry, dropping its reference count */
 int
-icl_SetFree(register struct afs_icl_set *setp)
+icl_SetFree(struct afs_icl_set *setp)
 {
     setp->states |= ICL_SETF_DELETED;
     icl_SetRele(setp);
@@ -1354,7 +1336,7 @@ icl_SetFree(register struct afs_icl_set *setp)
 struct afs_icl_set *
 icl_FindSet(char *name)
 {
-    register struct afs_icl_set *tp;
+    struct afs_icl_set *tp;
 
     for (tp = icl_allSets; tp; tp = tp->nextp) {
 	if (strcmp(tp->name, name) == 0) {
@@ -1370,7 +1352,7 @@ icl_FindSet(char *name)
 int
 icl_ZeroSet(struct afs_icl_set *setp)
 {
-    register int i;
+    int i;
     int code = 0;
     int tcode;
     struct afs_icl_log *logp;
@@ -1389,11 +1371,11 @@ icl_ZeroSet(struct afs_icl_set *setp)
 }
 
 int
-icl_EnumerateSets(int (*aproc) (char *, void *, struct afs_icl_set *), 
+icl_EnumerateSets(int (*aproc) (char *, void *, struct afs_icl_set *),
 		  void *arock)
 {
-    register struct afs_icl_set *tp, *np;
-    register afs_int32 code;
+    struct afs_icl_set *tp, *np;
+    afs_int32 code;
 
     code = 0;
     for (tp = icl_allSets; tp; tp = np) {
@@ -1411,7 +1393,7 @@ icl_EnumerateSets(int (*aproc) (char *, void *, struct afs_icl_set *),
 int
 icl_AddLogToSet(struct afs_icl_set *setp, struct afs_icl_log *newlogp)
 {
-    register int i;
+    int i;
     int code = -1;
 
     for (i = 0; i < ICL_LOGSPERSET; i++) {
@@ -1468,7 +1450,7 @@ icl_SetSetStat(struct afs_icl_set *setp, int op)
 	break;
 
     case ICL_OP_SS_FREE:	/* deassert design for log */
-	/* 
+	/*
 	 * if we are already in this state, do nothing; otherwise
 	 * deassert desire for log
 	 */
@@ -1501,7 +1483,7 @@ struct afs_icl_log *afs_icl_allLogs = 0;
 
 /* hold and release logs */
 int
-icl_LogHold(register struct afs_icl_log *logp)
+icl_LogHold(struct afs_icl_log *logp)
 {
     logp->refCount++;
     return 0;
@@ -1509,7 +1491,7 @@ icl_LogHold(register struct afs_icl_log *logp)
 
 /* hold and release logs, called with lock already held */
 int
-icl_LogHoldNL(register struct afs_icl_log *logp)
+icl_LogHoldNL(struct afs_icl_log *logp)
 {
     logp->refCount++;
     return 0;
@@ -1517,7 +1499,7 @@ icl_LogHoldNL(register struct afs_icl_log *logp)
 
 /* keep track of how many sets believe the log itself is allocated */
 int
-icl_LogUse(register struct afs_icl_log *logp)
+icl_LogUse(struct afs_icl_log *logp)
 {
     if (logp->setCount == 0) {
 	/* this is the first set actually using the log -- allocate it */
@@ -1525,8 +1507,7 @@ icl_LogUse(register struct afs_icl_log *logp)
 	    /* we weren't passed in a hint and it wasn't set */
 	    logp->logSize = ICL_DEFAULT_LOGSIZE;
 	}
-	logp->datap =
-	    (afs_int32 *) osi_Alloc(sizeof(afs_int32) * logp->logSize);
+	logp->datap = osi_Alloc(sizeof(afs_int32) * logp->logSize);
     }
     logp->setCount++;
     return 0;
@@ -1534,7 +1515,7 @@ icl_LogUse(register struct afs_icl_log *logp)
 
 /* decrement the number of real users of the log, free if possible */
 int
-icl_LogFreeUse(register struct afs_icl_log *logp)
+icl_LogFreeUse(struct afs_icl_log *logp)
 {
     if (--logp->setCount == 0) {
 	/* no more users -- free it (but keep log structure around) */
@@ -1548,7 +1529,7 @@ icl_LogFreeUse(register struct afs_icl_log *logp)
 
 /* set the size of the log to 'logSize' */
 int
-icl_LogSetSize(register struct afs_icl_log *logp, afs_int32 logSize)
+icl_LogSetSize(struct afs_icl_log *logp, afs_int32 logSize)
 {
     if (!logp->datap) {
 	/* nothing to worry about since it's not allocated */
@@ -1560,7 +1541,7 @@ icl_LogSetSize(register struct afs_icl_log *logp, afs_int32 logSize)
 
 	/* free and allocate a new one */
 	osi_Free(logp->datap, sizeof(afs_int32) * logp->logSize);
-	logp->datap = (afs_int32 *) osi_Alloc(sizeof(afs_int32) * logSize);
+	logp->datap = osi_Alloc(sizeof(afs_int32) * logSize);
 	logp->logSize = logSize;
     }
 
@@ -1569,9 +1550,9 @@ icl_LogSetSize(register struct afs_icl_log *logp, afs_int32 logSize)
 
 /* free a log.  Called with icl_lock locked. */
 int
-icl_ZapLog(register struct afs_icl_log *logp)
+icl_ZapLog(struct afs_icl_log *logp)
 {
-    register struct afs_icl_log **lpp, *tp;
+    struct afs_icl_log **lpp, *tp;
 
     for (lpp = &afs_icl_allLogs, tp = *lpp; tp; lpp = &tp->nextp, tp = *lpp) {
 	if (tp == logp) {
@@ -1588,7 +1569,7 @@ icl_ZapLog(register struct afs_icl_log *logp)
 
 /* do the release, watching for deleted entries */
 int
-icl_LogRele(register struct afs_icl_log *logp)
+icl_LogRele(struct afs_icl_log *logp)
 {
     if (--logp->refCount == 0 && (logp->states & ICL_LOGF_DELETED)) {
 	icl_ZapLog(logp);	/* destroys logp's lock! */
@@ -1598,7 +1579,7 @@ icl_LogRele(register struct afs_icl_log *logp)
 
 /* do the release, watching for deleted entries, log already held */
 int
-icl_LogReleNL(register struct afs_icl_log *logp)
+icl_LogReleNL(struct afs_icl_log *logp)
 {
     if (--logp->refCount == 0 && (logp->states & ICL_LOGF_DELETED)) {
 	icl_ZapLog(logp);	/* destroys logp's lock! */
@@ -1608,7 +1589,7 @@ icl_LogReleNL(register struct afs_icl_log *logp)
 
 /* zero out the log */
 int
-icl_ZeroLog(register struct afs_icl_log *logp)
+icl_ZeroLog(struct afs_icl_log *logp)
 {
     logp->firstUsed = logp->firstFree = 0;
     logp->logElements = 0;
@@ -1617,7 +1598,7 @@ icl_ZeroLog(register struct afs_icl_log *logp)
 
 /* free a log entry, and drop its reference count */
 int
-icl_LogFree(register struct afs_icl_log *logp)
+icl_LogFree(struct afs_icl_log *logp)
 {
     logp->states |= ICL_LOGF_DELETED;
     icl_LogRele(logp);
@@ -1630,8 +1611,8 @@ icl_EnumerateLogs(int (*aproc)
 		    (char *name, void *arock, struct afs_icl_log * tp),
 		  void *arock)
 {
-    register struct afs_icl_log *tp;
-    register afs_int32 code;
+    struct afs_icl_log *tp;
+    afs_int32 code;
 
     code = 0;
     for (tp = afs_icl_allLogs; tp; tp = tp->nextp) {
@@ -1655,14 +1636,13 @@ GetBulkSetInfo(void)
 	sizeof(afs_icl_bulkSetinfo_t) + (ICL_RPC_MAX_SETS -
 					 1) * sizeof(afs_icl_setinfo_t);
     if (!setInfo) {
-	setInfo = (afs_icl_bulkSetinfo_t *) malloc(infoSize);
+	setInfo = calloc(1, infoSize);
 	if (!setInfo) {
 	    (void)fprintf(stderr,
 			  "Could not allocate the memory for bulk set info structure\n");
 	    exit(1);
 	}
     }
-    memset(setInfo, 0, infoSize);
 
     return setInfo;
 }
@@ -1676,7 +1656,7 @@ GetBulkLogInfo(void)
 	sizeof(afs_icl_bulkLoginfo_t) + (ICL_RPC_MAX_LOGS -
 					 1) * sizeof(afs_icl_loginfo_t);
     if (!logInfo) {
-	logInfo = (afs_icl_bulkLoginfo_t *) malloc(infoSize);
+	logInfo = calloc(1, infoSize);
 	if (!logInfo) {
 	    (void)fprintf(stderr,
 			  "Could not allocate the memory for bulk log info structure\n");
@@ -1684,7 +1664,6 @@ GetBulkLogInfo(void)
 	}
     }
 
-    memset(logInfo, 0, infoSize);
     return logInfo;
 }
 
@@ -1765,17 +1744,19 @@ SetUpDump(void)
 
     dumpSyntax =
 	cmd_CreateSyntax("dump", DoDump, NULL, "dump AFS trace logs");
-    (void)cmd_AddParm(dumpSyntax, "-set", CMD_LIST, CMD_OPTIONAL, "set_name");
+    (void)cmd_AddParm(dumpSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
+		      "event set name");
     (void)cmd_AddParm(dumpSyntax, "-follow", CMD_SINGLE, CMD_OPTIONAL,
-		      "log_name");
+		      "trace log name");
     (void)cmd_AddParm(dumpSyntax, "-file", CMD_SINGLE, CMD_OPTIONAL,
-		      "output_filename");
+		      "path to trace log file for writing");
     (void)cmd_AddParm(dumpSyntax, "-sleep", CMD_SINGLE, CMD_OPTIONAL,
-		      "seconds_between_reads");
+		      "interval (secs) for writes when using -follow");
 }
 
+
 static int
-DoShowLog(register struct cmd_syndesc *as, void *arock)
+DoShowLog(struct cmd_syndesc *as, void *arock)
 {
     afs_int32 retVal = 0;
     afs_int32 code = 0;
@@ -1840,13 +1821,16 @@ SetUpShowLog(void)
     showSyntax =
 	cmd_CreateSyntax("lslog", DoShowLog, NULL,
 			 "list available logs");
-    (void)cmd_AddParm(showSyntax, "-set", CMD_LIST, CMD_OPTIONAL, "set_name");
-    (void)cmd_AddParm(showSyntax, "-log", CMD_LIST, CMD_OPTIONAL, "log_name");
-    (void)cmd_AddParm(showSyntax, "-long", CMD_FLAG, CMD_OPTIONAL, "");
+    (void)cmd_AddParm(showSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
+		      "event set name");
+    (void)cmd_AddParm(showSyntax, "-log", CMD_LIST, CMD_OPTIONAL,
+		      "trace log name");
+    (void)cmd_AddParm(showSyntax, "-long", CMD_FLAG, CMD_OPTIONAL,
+		      "show defined log size in kbytes & if it is allocated in kernel mem");
 }
 
 static int
-DoShowSet(register struct cmd_syndesc *as, void *arock)
+DoShowSet(struct cmd_syndesc *as, void *arock)
 {
     afs_int32 retVal = 0;
     afs_int32 code = 0;
@@ -1896,11 +1880,12 @@ SetUpShowSet(void)
     showSyntax =
 	cmd_CreateSyntax("lsset", DoShowSet, NULL,
 			 "list available event sets");
-    (void)cmd_AddParm(showSyntax, "-set", CMD_LIST, CMD_OPTIONAL, "set_name");
+    (void)cmd_AddParm(showSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
+		      "event set name");
 }
 
 static int
-DoClear(register struct cmd_syndesc *as, void *arock)
+DoClear(struct cmd_syndesc *as, void *arock)
 {
     afs_int32 retVal = 0;
     afs_int32 code = 0;
@@ -1954,13 +1939,13 @@ SetUpClear(void)
 	cmd_CreateSyntax("clear", DoClear, NULL,
 			 "clear logs by logname or by event set");
     (void)cmd_AddParm(clearSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
-		      "set_name");
+		      "event set name");
     (void)cmd_AddParm(clearSyntax, "-log", CMD_LIST, CMD_OPTIONAL,
-		      "log_name");
+		      "trace log name");
 }
 
 static int
-DoSet(register struct cmd_syndesc *as, void *arock)
+DoSet(struct cmd_syndesc *as, void *arock)
 {
     afs_int32 retVal = 0;
     afs_int32 code = 0;
@@ -2040,14 +2025,18 @@ SetUpSet(void)
     setSyntax =
 	cmd_CreateSyntax("setset", DoSet, NULL,
 			 "set state of event sets");
-    (void)cmd_AddParm(setSyntax, "-set", CMD_LIST, CMD_OPTIONAL, "set_name");
-    (void)cmd_AddParm(setSyntax, "-active", CMD_FLAG, CMD_OPTIONAL, "");
-    (void)cmd_AddParm(setSyntax, "-inactive", CMD_FLAG, CMD_OPTIONAL, "");
-    (void)cmd_AddParm(setSyntax, "-dormant", CMD_FLAG, CMD_OPTIONAL, "");
+    (void)cmd_AddParm(setSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
+		      "event set name");
+    (void)cmd_AddParm(setSyntax, "-active", CMD_FLAG, CMD_OPTIONAL,
+		      "enable tracing for event set & allocate kernel memory");
+    (void)cmd_AddParm(setSyntax, "-inactive", CMD_FLAG, CMD_OPTIONAL,
+		      "disables tracing for event set, keep kernel memory");
+    (void)cmd_AddParm(setSyntax, "-dormant", CMD_FLAG, CMD_OPTIONAL,
+		      "disable tracing for event set & free kernel memory");
 }
 
 static int
-DoResize(register struct cmd_syndesc *as, void *arock)
+DoResize(struct cmd_syndesc *as, void *arock)
 {
     afs_int32 retVal = 0;
     afs_int32 code = 0;
@@ -2098,9 +2087,9 @@ SetUpResize(void)
 	cmd_CreateSyntax("setlog", DoResize, NULL,
 			 "set the size of a log");
     (void)cmd_AddParm(setsizeSyntax, "-log", CMD_LIST, CMD_OPTIONAL,
-		      "log_name");
+		      "trace log name");
     (void)cmd_AddParm(setsizeSyntax, "-buffersize", CMD_SINGLE, CMD_REQUIRED,
-		      "1-kilobyte_units");
+		      "# of 1-kbyte blocks to allocate for log");
 }
 
 #include "AFS_component_version_number.c"
@@ -2123,12 +2112,3 @@ main(int argc, char *argv[])
 
     return (cmd_Dispatch(argc, argv));
 }
-#else
-#include "AFS_component_version_number.c"
-
-int
-main(int argc, char *argv[])
-{
-    printf("fstrace is NOT supported for this OS\n");
-}
-#endif
