@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -9,16 +9,12 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-
 #include <afs/stds.h>
-#include <sys/types.h>
-#include <errno.h>
-#include <stdio.h>
-#include <sys/file.h>
-#include <string.h>
 
-#include <netinet/in.h>
+#include <roken.h>
+
+#include <sys/file.h>
+
 #include <afs/venus.h>
 #include <afs/cmd.h>
 #include <afs/afsutil.h>
@@ -34,7 +30,7 @@ static char pn[] = "cnvldb";
 static char tempname[] = "XXnewvldb";
 static int MaxServers[3] = { 30, 254, 254 };	/* max server # permitted in this version */
 
-static afs_int32 Conv4to3(afs_int32 addr);
+static afs_int32 Conv4to3(afs_uint32 addr);
 
 static void convert_vlentry(int, int, int, struct vlheader_1 *,
 			    struct vlheader_1 *, struct vlentry_1 *);
@@ -55,7 +51,7 @@ static int convert_header(int ofd, int fd, int fromv, int tov, void *fromaddr,
 static char *
 Parent(const char *apath)
 {
-    register char *tp;
+    char *tp;
     strcpy(tspace, apath);
     tp = strrchr(tspace, '/');
     if (tp) {
@@ -210,7 +206,7 @@ handleit(struct cmd_syndesc *as, void *arock)
 	exit(1);
     }
 
-    /* Because we know that all the vldb entries are the same size and type we 
+    /* Because we know that all the vldb entries are the same size and type we
      * can just read them sequentially, fiddle with the fields, and write
      * them out again.  If we invent a vldb format that has different
      * types of entries, then we're going to have to invent new logic for
@@ -243,7 +239,7 @@ handleit(struct cmd_syndesc *as, void *arock)
     }
     close(new);
 
-    renamefile(tempname, pathname);
+    rk_rename(tempname, pathname);
     sleep(5);
     exit(0);
 }
@@ -377,7 +373,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
     if (!mh_addr)
 	return;
 
-    /* Check if the first extent block is beyond eof. If 
+    /* Check if the first extent block is beyond eof. If
      * it is, it's not real.
      */
     if (mh_addr > dbsize - VL_ADDREXTBLK_SIZE)
@@ -389,7 +385,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
 	perror("seek MH block");
 	exit(1);
     }
-    base[0] = (struct extentaddr *)malloc(VL_ADDREXTBLK_SIZE);
+    base[0] = malloc(VL_ADDREXTBLK_SIZE);
     if (!base[0]) {
 	perror("malloc1");
 	exit(1);
@@ -403,7 +399,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
     }
 
     /* Verify that this block is the right one */
-    if (ntohl(base[0]->ex_flags) != VLCONTBLOCK) {	/* check if flag is correct */
+    if (ntohl(base[0]->ex_hdrflags) != VLCONTBLOCK) {	/* check if flag is correct */
 	free(base[0]);
 	base[0] = 0;
 	return;
@@ -419,7 +415,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
 
 	sit = ntohl(base[0]->ex_contaddrs[j]);
 
-	/* Every time we allocate a new extent block, it is allocated after 
+	/* Every time we allocate a new extent block, it is allocated after
 	 * the previous ones. But it must be before the EOF.
 	 */
 	if ((sit < (a + VL_ADDREXTBLK_SIZE))
@@ -434,7 +430,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
 	    perror("seek MH block");
 	    exit(1);
 	}
-	base[j] = (struct extentaddr *)malloc(VL_ADDREXTBLK_SIZE);
+	base[j] = malloc(VL_ADDREXTBLK_SIZE);
 	if (!base[j]) {
 	    perror("malloc1");
 	    exit(1);
@@ -446,7 +442,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
 	}
 
 	/* Verify that this block knows its an extent block */
-	if (ntohl(base[j]->ex_flags) != VLCONTBLOCK) {
+	if (ntohl(base[j]->ex_hdrflags) != VLCONTBLOCK) {
 	    free(base[j]);
 	    base[j] = 0;
 	    continue;
@@ -461,7 +457,7 @@ read_mhentries(afs_uint32 mh_addr, int oldfd)
  * extent blocks and verify that the pointers are good. And fix.
  * Then convert the multihomed addresses to single address if we
  * are converting back from version 4.
- * 
+ *
  * Before this can be called, the routine read_mhentries must be called.
  */
 void
@@ -525,7 +521,7 @@ convert_mhentries(int oldfd, int newfd, struct vlheader_2 *header,
 	}
     }
 
-    /* If we are converting from version 4 to version 3, then 
+    /* If we are converting from version 4 to version 3, then
      * translate any multihome ptrs in the IpMappedAddr array
      * to true IP addresses.
      */
@@ -734,7 +730,7 @@ convert_header(int ofd, int fd, int fromv, int tov, void *fromaddr,
 
 /* Convert an address pointer to a vlentry from version 4 to version 3.
  * This involves checking if the address is after any of the four
- * MH block and if it is, subtract the size of the MH block. 
+ * MH block and if it is, subtract the size of the MH block.
  *
  * In going from version 4 to 3, the mh blocks go away and all entries
  * move up in their place. The adresses then need to be updated.
@@ -742,9 +738,9 @@ convert_header(int ofd, int fd, int fromv, int tov, void *fromaddr,
  * Before this can be called, the routine read_mhentries must be called.
  */
 static afs_int32
-Conv4to3(afs_int32 addr)
+Conv4to3(afs_uint32 addr)
 {
-    afs_int32 raddr;
+    afs_uint32 raddr;
     int i;
 
     if (!base[0] || !addr)
@@ -760,7 +756,7 @@ Conv4to3(afs_int32 addr)
     return (raddr);
 }
 
-/* this only works because the vlheader struct is essentially the same 
+/* this only works because the vlheader struct is essentially the same
  * from version 1 to version 2 -- that is, the first bunch of fields
  * aren't any more or any larger, so they match up pretty well.
 */
@@ -979,7 +975,7 @@ rewrite_header(int new, int tovers, void *newheader)
 int
 main(int argc, char **argv)
 {
-    register struct cmd_syndesc *ts;
+    struct cmd_syndesc *ts;
     afs_int32 code;
 
     ts = cmd_CreateSyntax("initcmd", handleit, NULL, "optional");
