@@ -24,9 +24,9 @@
 #include <WINNT/afsevent.h>
 #endif
 
-#include <rx/xdr.h>
+#include <afs/opr.h>
+#include <opr/lock.h>
 #include <afs/afsint.h>
-#include <afs/afs_assert.h>
 
 #ifndef AFS_NT40_ENV
 #include <afs/osi_inode.h>
@@ -36,9 +36,9 @@
 #include <afs/dir.h>
 #include <afs/afsutil.h>
 #include <afs/fileutil.h>
+#include <rx/rx_queue.h>
 
 #include "nfs.h"
-#include "lwp.h"
 #include "lock.h"
 #include "ihandle.h"
 #include "vnode.h"
@@ -352,7 +352,7 @@ common_volop_prolog(struct cmd_syndesc * as, struct fssync_state * state)
     struct cmd_item *ti;
 
     state->vop = (struct volop_state *) calloc(1, sizeof(struct volop_state));
-    osi_Assert(state->vop != NULL);
+    opr_Assert(state->vop != NULL);
 
     if ((ti = as->parms[COMMON_VOLOP_PARMS_OFFSET].items)) {	/* -volumeid */
 	state->vop->volume = atoi(ti->data);
@@ -446,6 +446,10 @@ VolOnline(struct cmd_syndesc * as, void * rock)
     common_prolog(as, &state);
     common_volop_prolog(as, &state);
 
+    if (state.vop->partName==0 || *(state.vop->partName)==0) {
+	fprintf(stderr, "required argument -partition not given\n");
+	return -1;
+    }
     do_volop(&state, FSYNC_VOL_ON, NULL);
 
     return 0;
@@ -853,11 +857,7 @@ VolHdrQuery(struct cmd_syndesc * as, void * rock)
 	printf("\texpirationDate   = %u\n", v.expirationDate);
 	printf("\tbackupDate       = %u\n", v.backupDate);
 	printf("\tcopyDate         = %u\n", v.copyDate);
-#ifdef OPENAFS_VOL_STATS
 	printf("\tstat_initialized = %d\n", v.stat_initialized);
-#else
-        printf("\tmtd              = '%s'\n", v.motd);
-#endif
 	printf("}\n");
     }
 
